package com.moyoung.moyoung_ble_plugin.common;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.Map;

public class ConstraintsMap {

    private final Map<String, Object> map;

    public ConstraintsMap(){
        map = new HashMap<>();
    }

    public ConstraintsMap(Map<String, Object> map){
        this.map = map;
    }

    public Map<String, Object> toMap() {
        return map;
    }

    public boolean hasKey(String name){
        return this.map.containsKey(name);
    }

    public boolean isNull(String name){
        return map.get(name) == null;
    }

    public boolean getBoolean(String name){
        return (boolean) map.get(name);
    }

    public double getDouble(String name){
        return (double) map.get(name);
    }

    public int getInt(String name) {
        if(getType(name) == ObjectType.String) {
            return Integer.parseInt(((String) map.get(name)));
        }
        return (int) map.get(name);
    }

    public String getString(String name){
        return (String) map.get(name);
    }

    public ConstraintsMap getMap(String name){
        return new ConstraintsMap((Map<String, Object>) map.get(name));
    }

    public ObjectType getType(String name) {
        Object value = map.get(name);
        if (value == null) {
            return ObjectType.Null;
        } else if (value instanceof Number) {
            return ObjectType.Number;
        } else if (value instanceof String) {
            return ObjectType.String;
        } else if (value instanceof Boolean) {
            return ObjectType.Boolean;
        } else if (value instanceof Map) {
            return ObjectType.Map;
        } else if (value instanceof ArrayList) {
            return ObjectType.Array;
        } else {
            throw new IllegalArgumentException("Invalid value " + value.toString() + " for key " + name +
                    "contained in ConstraintsMap");
        }
    }

    public void putBoolean(String key, boolean value) {
        map.put(key, value);
    }

    public void putDouble(String key, double value) {
        map.put(key, value);
    }

    public void putInt(String key, int value) {
        map.put(key, value);
    }

    public void putString(String key, String value) {
        map.put(key, value);
    }

    public void putNull(String key) {
        map.put(key, null);
    }

    public void putMap(String key, Map<String, Object> value) {
        map.put(key, value);
    }

    public void merge(Map<String, Object> value) {
        map.putAll(value);
    }

    public void putArray(String key, ArrayList<Object> value) {
        map.put(key, value);
    }

}
