package com.moyoung.moyoung_ble_plugin.conn;

import android.app.Activity;
import android.content.Context;
import android.util.Log;

import com.crrepa.ble.conn.CRPBleConnection;
import com.moyoung.moyoung_ble_plugin.base.BaseConnEveChlHandler;
import com.moyoung.moyoung_ble_plugin.base.BaseConnLazyEveChlHandler;
import com.moyoung.moyoung_ble_plugin.common.CommonMethods;

import java.util.ArrayList;
import java.util.List;

import androidx.annotation.NonNull;
import io.flutter.plugin.common.BinaryMessenger;
import io.flutter.plugin.common.EventChannel;
import io.flutter.plugin.common.MethodCall;

import static com.moyoung.moyoung_ble_plugin.ChannelConstant.EVE_CHL_CONN_BLOOD_OXYGEN;
import static com.moyoung.moyoung_ble_plugin.ChannelConstant.EVE_CHL_CONN_BLOOD_PRESSURE;
import static com.moyoung.moyoung_ble_plugin.ChannelConstant.EVE_CHL_CONN_CAMERA;
import static com.moyoung.moyoung_ble_plugin.ChannelConstant.EVE_CHL_CONN_DEVICE_RSSI;
import static com.moyoung.moyoung_ble_plugin.ChannelConstant.EVE_CHL_CONN_PHONE;
import static com.moyoung.moyoung_ble_plugin.ChannelConstant.EVE_CHL_CONN_STATE;
import static com.moyoung.moyoung_ble_plugin.ChannelConstant.EVE_CHL_CONN_STEP_CHANGE;
import static com.moyoung.moyoung_ble_plugin.ChannelConstant.EVE_CHL_CONN_HEART_RATE;
import static com.moyoung.moyoung_ble_plugin.ChannelConstant.EVE_CHL_CONN_TAIN_STATE;
import static com.moyoung.moyoung_ble_plugin.ChannelConstant.EVE_CHL_CONN_TEMP_CHANGE;
import static com.moyoung.moyoung_ble_plugin.ChannelConstant.EVE_CHL_CONN_CONTACT;
import static com.moyoung.moyoung_ble_plugin.ChannelConstant.EVE_CHL_CONN_BATTERY_SAVING;
import static com.moyoung.moyoung_ble_plugin.ChannelConstant.EVE_CHL_CONN_TRAIN;
import static com.moyoung.moyoung_ble_plugin.ChannelConstant.LAZY_EVE_CHL_CONN_CONTACT_AVATAR;
import static com.moyoung.moyoung_ble_plugin.ChannelConstant.LAZY_EVE_CHL_CONN_EGC;
import static com.moyoung.moyoung_ble_plugin.ChannelConstant.LAZY_EVE_CHL_CONN_FILE_TRANS;
import static com.moyoung.moyoung_ble_plugin.ChannelConstant.LAZY_EVE_CHL_CONN_WF_FILE_TRANS;

public class ConnEveChlRegister {
    private final static String TAG = ConnEveChlRegister.class.getSimpleName();

    private final List<EventChannel> eveChlList = new ArrayList<>();
    private final List<BaseConnEveChlHandler> connHandlerList = new ArrayList<>();
    private final List<BaseConnLazyEveChlHandler> connLazyHandlerList = new ArrayList<>();
    private final BinaryMessenger binaryMgr;

    public ConnEveChlRegister(BinaryMessenger binaryMessenger) {
        this.binaryMgr = binaryMessenger;
    }

    public void register() {
        registerEveChl(new ConnStateEveChlHandler(), EVE_CHL_CONN_STATE);
        registerEveChl(new ConnStepChangeEveChlHandler(), EVE_CHL_CONN_STEP_CHANGE);
        //余诗霞：start
        registerEveChl(new ConnHeartRateEveChlHandler(), EVE_CHL_CONN_HEART_RATE);
        registerEveChl(new ConnBloodPressureEveChlHandler(), EVE_CHL_CONN_BLOOD_PRESSURE);
        registerEveChl(new ConnBloodOxygenEveChlHandler(), EVE_CHL_CONN_BLOOD_OXYGEN);
        registerEveChl(new ConnCameraEveChlHandler(), EVE_CHL_CONN_CAMERA);
        registerEveChl(new ConnPhoneEveChlHandler(), EVE_CHL_CONN_PHONE);
        registerEveChl(new ConnDeviceRssiEveChlHandler(), EVE_CHL_CONN_DEVICE_RSSI);
        registerLazyEveChl(new ConnFileTransLazyEveChlHandler(), LAZY_EVE_CHL_CONN_FILE_TRANS);
        registerLazyEveChl(new ConnWFFileTransLazyEveChlHandler(), LAZY_EVE_CHL_CONN_WF_FILE_TRANS);
        registerLazyEveChl(new ConnEGCEveChlHandler(), LAZY_EVE_CHL_CONN_EGC);
        //该监听为李宝忠的监听
        registerLazyEveChl(new ConnContactAvatarLazyEveChlHandler(), LAZY_EVE_CHL_CONN_CONTACT_AVATAR);
        //余诗霞：end
        // libaozhong: start
        registerEveChl(new ConnTainStateEveChlHandler(), EVE_CHL_CONN_TAIN_STATE);
        registerEveChl(new ConnTempChangeHandler(), EVE_CHL_CONN_TEMP_CHANGE);
        registerEveChl(new ConnContactHandler(), EVE_CHL_CONN_CONTACT);
        registerEveChl(new ConnBatterySavingHandler(), EVE_CHL_CONN_BATTERY_SAVING);
        registerEveChl(new ConnTrainHandler(), EVE_CHL_CONN_TRAIN);
        // libaozhong: end
    }

    public void unregister() {
        for (EventChannel eventChannel : eveChlList) {
            eventChannel.setStreamHandler(null);
        }
    }

    public void bindActivity(Activity activity) {
        for (BaseConnEveChlHandler chlHandler : connHandlerList) {
            chlHandler.bindActivity(activity);
        }
        for (BaseConnLazyEveChlHandler chlHandler : connLazyHandlerList) {
            chlHandler.bindActivity(activity);
        }
    }

    public BaseConnLazyEveChlHandler getLazyEveChlHandler(String chlName) {
        for (BaseConnLazyEveChlHandler baseConnLazyEveChlHandler : connLazyHandlerList) {
            if (chlName.equals(baseConnLazyEveChlHandler.getBelongChl())) {
                return baseConnLazyEveChlHandler;
            }
        }

        return null;
    }

    public CRPBleConnection connect(@NonNull MethodCall call, Context context) {
        String address = call.argument("address");
        CRPBleConnection connection = CommonMethods.connect(context, address);
        if (connection == null) {
            Log.d(TAG, "Connection获取为空");
            return null;
        }

        for (BaseConnEveChlHandler handler : connHandlerList) {
            handler.setConnListener(connection);
        }
        return connection;
    }

    private void registerEveChl(BaseConnEveChlHandler eveChlHandler, String chlName) {
        EventChannel bleConnectEveChl = new EventChannel(binaryMgr, chlName);
        bleConnectEveChl.setStreamHandler(eveChlHandler);

        eveChlList.add(bleConnectEveChl);
        connHandlerList.add(eveChlHandler);
    }

    private void registerLazyEveChl(BaseConnLazyEveChlHandler lazyEveChlHandler, String chlName) {
        EventChannel bleConnectEveChl = new EventChannel(binaryMgr, chlName);
        bleConnectEveChl.setStreamHandler(lazyEveChlHandler);

        lazyEveChlHandler.setBelongChl(chlName);

        eveChlList.add(bleConnectEveChl);
        connLazyHandlerList.add(lazyEveChlHandler);
    }
}
