package com.moyoung.moyoung_ble_plugin.conn;

import android.app.Activity;
import android.bluetooth.BluetoothAdapter;
import android.content.Intent;
import android.util.Log;

import com.crrepa.ble.conn.CRPBleConnection;
import com.crrepa.ble.conn.CRPBleDevice;
import com.crrepa.ble.conn.bean.CRPAlarmClockInfo;
import com.crrepa.ble.conn.bean.CRPContactInfo;
import com.crrepa.ble.conn.bean.CRPDrinkWaterPeriodInfo;
import com.crrepa.ble.conn.bean.CRPFirmwareVersionInfo;
import com.crrepa.ble.conn.bean.CRPFutureWeatherInfo;
import com.crrepa.ble.conn.bean.CRPHandWashingPeriodInfo;
import com.crrepa.ble.conn.bean.CRPMessageInfo;
import com.crrepa.ble.conn.bean.CRPPeriodTimeInfo;
import com.crrepa.ble.conn.bean.CRPPhysiologcalPeriodInfo;
import com.crrepa.ble.conn.bean.CRPPillReminderInfo;
import com.crrepa.ble.conn.bean.CRPSedentaryReminderPeriodInfo;
import com.crrepa.ble.conn.bean.CRPSupportWatchFaceInfo;
import com.crrepa.ble.conn.bean.CRPTodayWeatherInfo;
import com.crrepa.ble.conn.bean.CRPUserInfo;
import com.crrepa.ble.conn.bean.CRPWatchFaceInfo;
import com.crrepa.ble.conn.bean.CRPWatchFaceLayoutInfo;
import com.crrepa.ble.conn.callback.CRPDeviceBreathingLightCallback;
import com.crrepa.ble.conn.callback.CRPDeviceLanguageCallback;
import com.crrepa.ble.conn.callback.CRPDeviceNewFirmwareVersionCallback;
import com.crrepa.ble.conn.callback.CRPDevicePeriodTimeCallback;
import com.crrepa.ble.conn.callback.CRPDeviceSedentaryReminderCallback;
import com.crrepa.ble.conn.callback.CRPDeviceSedentaryReminderPeriodCallback;
import com.crrepa.ble.conn.callback.CRPDeviceWatchFaceCallback;
import com.crrepa.ble.conn.callback.CRPDeviceWatchFaceStoreCallback;
import com.crrepa.ble.conn.type.CRPBloodOxygenTimeType;
import com.crrepa.ble.conn.type.CRPDeviceLanguageType;
import com.crrepa.ble.conn.type.CRPDeviceVersionType;
import com.crrepa.ble.conn.type.CRPFirmwareUpgradeType;
import com.crrepa.ble.conn.type.CRPHeartRateType;
import com.crrepa.ble.conn.type.CRPHistoryDynamicRateType;
import com.crrepa.ble.conn.type.CRPMetricSystemType;
import com.crrepa.ble.conn.type.CRPMusicPlayerStateType;
import com.crrepa.ble.conn.type.CRPTempTimeType;
import com.crrepa.ble.conn.type.CRPTimeSystemType;
import com.crrepa.ble.conn.type.CRPTimingTempState;
import com.crrepa.ble.conn.type.CRPWatchFaceType;
import com.moyoung.moyoung_ble_plugin.base.BaseChlHandler;
import com.moyoung.moyoung_ble_plugin.base.BaseConnLazyEveChlHandler;
import com.moyoung.moyoung_ble_plugin.common.ConstraintsMap;
import com.moyoung.moyoung_ble_plugin.common.GsonUtils;
import com.moyoung.moyoung_ble_plugin.conn.model.CRPContactBean;
import com.moyoung.moyoung_ble_plugin.conn.model.WatchFaceStoreBean;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import androidx.annotation.NonNull;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;

import static com.moyoung.moyoung_ble_plugin.ChannelConstant.LAZY_EVE_CHL_CONN_CONTACT_AVATAR;
import static com.moyoung.moyoung_ble_plugin.ChannelConstant.LAZY_EVE_CHL_CONN_EGC;
import static com.moyoung.moyoung_ble_plugin.ChannelConstant.LAZY_EVE_CHL_CONN_FILE_TRANS;
import static com.moyoung.moyoung_ble_plugin.ChannelConstant.LAZY_EVE_CHL_CONN_WF_FILE_TRANS;

public class ConnMethodChlHandler extends BaseChlHandler implements MethodChannel.MethodCallHandler {
    private final static String TAG = ConnMethodChlHandler.class.getSimpleName();

    private final ConnEveChlRegister connEveChlRegister;
    private CRPBleConnection bleConnection;

    public ConnMethodChlHandler(ConnEveChlRegister connEveChlRegister) {
        this.connEveChlRegister = connEveChlRegister;
    }

    @Override
    public void bindActivity(Activity activity) {
        super.bindActivity(activity);
        connEveChlRegister.bindActivity(this.activity);
    }

    public void unbindChannel(MethodChannel methodChannel) {
        methodChannel.setMethodCallHandler(null);
        connEveChlRegister.unregister();
    }

    @Override
    public void onMethodCall(@NonNull MethodCall call, @NonNull MethodChannel.Result result) {
        if (!checkBluetoothEnable()) {
            return;
        }

        switch (call.method) {
            case "connect":
                bleConnection = connEveChlRegister.connect(call, activity.getApplicationContext());
                break;
            case "disconnect":
                closeGatt(result);
                break;
            case "isConnected":
                isConnected(call, result);
                break;
            case "syncTime":
                bleConnection.syncTime();
                break;
            case "sendTimeSystem":
                sendTimeSystem(call);
                break;
            case "queryFirmwareVersion":
                queryFirmwareVersion(result);
                break;
            case "queryTimeSystem":
                queryTimeSystem(result);
                break;
            case "checkFirmwareVersion":
                checkFirmwareVersion(call, result);
                break;
            case "queryDeviceBattery":
                queryDeviceBattery();
                break;
            case "subscribeDeviceBattery":
                subscribeDeviceBattery();
                break;
            case "sendUserInfo":
                sendUserInfo(call);
                break;
            case "sendStepLength":
                sendStepLength(call);
                break;
            case "sendTodayWeather":
                sendTodayWeather(call);
                break;
            case "sendFutureWeather":
                sendFutureWeather(call);
                break;
            //余诗霞:start
            case "queryMetricSystem":
                queryMetricSystem(result);
                break;
            case "sendMetricSystem":
                sendMetricSystem(call);
                break;
            case "sendQuickView":
                sendQuickView(call);
                break;
            case "queryQuickView":
                queryQuickView(result);
                break;
            case "sendQuickViewTime":
                sendQuickViewTime(call);
                break;
            case "queryQuickViewTime":
                queryQuickViewTime(result);
                break;
            case "sendGoalSteps":
                sendGoalSteps(call);
                break;
            case "queryGoalStep":
                queryGoalStep(result);
                break;
            //表盘
            case "sendDisplayWatchFace":
                sendDisplayWatchFace(call);
                break;
            case "queryDisplayWatchFace":
                queryDisplayWatchFace(result);
                break;
            case "queryWatchFaceLayout":
                queryWatchFaceLayout(result);
                break;
            case "sendWatchFaceLayout":
                sendWatchFaceLayout(call);
                break;
            case "querySupportWatchFace":
                querySupportWatchFace(result);
                break;
            case "queryWatchFaceStore":
                queryWatchFaceStore(call, result);
                break;
            case "queryWatchFaceOfID":
                queryWatchFaceOfID(call, result);
                break;
            case "sendWatchFace":
                sendWatchFace(call);
                break;
            case "sendAlarmClock":
                sendAlarmClock(call);
                break;
            case "queryAllAlarmClock":
                queryAllAlarmClock(result);
                break;
            case "queryLastDynamicRate":
                queryLastDynamicRate();
                break;
            case "enableTimingMeasureHeartRate":
                enableTimingMeasureHeartRate(call);
                break;
            case "disableTimingMeasureHeartRate":
                disableTimingMeasureHeartRate();
                break;
            case "queryTimingMeasureHeartRate":
                queryTimingMeasureHeartRate(result);
                break;
            case "queryTodayHeartRate":
                queryTodayHeartRate(call);
                break;
            case "queryPastHeartRate":
                queryPastHeartRate();
                break;
            case "queryMovementHeartRate":
                queryMovementHeartRate();
                break;
            case "startMeasureOnceHeartRate":
                startMeasureOnceHeartRate();
                break;
            case "stopMeasureOnceHeartRate":
                stopMeasureOnceHeartRate();
                break;
            case "queryHistoryHeartRate":
                queryHistoryHeartRate();
                break;
            //血压
            case "startMeasureBloodPressure":
                startMeasureBloodPressure();
                break;
            case "stopMeasureBloodPressure":
                stopMeasureBloodPressure();
                break;
            case "enableContinueBloodPressure":
                enableContinueBloodPressure();
                break;
            case "disableContinueBloodPressure":
                disableContinueBloodPressure();
                break;
            case "queryContinueBloodPressureState":
                queryContinueBloodPressureState();
                break;
            case "queryLast24HourBloodPressure":
                queryLast24HourBloodPressure();
                break;
            case "queryHistoryBloodPressure":
                queryHistoryBloodPressure();
                break;
            case "startMeasureBloodOxygen":
                startMeasureBloodOxygen();
                break;
            case "stopMeasureBloodOxygen":
                stopMeasureBloodOxygen();
                break;
            case "enableTimingMeasureBloodOxygen":
                enableTimingMeasureBloodOxygen(call);
                break;
            case "disableTimingMeasureBloodOxygen":
                disableTimingMeasureBloodOxygen();
                break;
            case "queryTimingBloodOxygenMeasureState":
                queryTimingBloodOxygenMeasureState();
                break;
            case "queryTimingBloodOxygen":
                queryTimingBloodOxygen(call);
                break;
            case "enableContinueBloodOxygen":
                enableContinueBloodOxygen();
                break;
            case "disableContinueBloodOxygen":
                disableContinueBloodOxygen();
                break;
            case "queryContinueBloodOxygenState":
                queryContinueBloodOxygenState();
                break;
            case "queryLast24HourBloodOxygen":
                queryLast24HourBloodOxygen();
                break;
            case "queryHistoryBloodOxygen":
                queryHistoryBloodOxygen();
                break;
            //拍照
            case "enterCameraView":
                enterCameraView();
                break;
            case "exitCameraView":
                exitCameraView();
                break;
            //rssi
            case "readDeviceRssi":
                readDeviceRssi();
                break;
            //egc
            case "setECGChangeListener":
                setECGChangeListener(call);
                break;
            case "startECGMeasure":
                startECGMeasure();
                break;
            case "stopECGMeasure":
                stopECGMeasure();
                break;
            case "isNewECGMeasurementVersion":
                isNewECGMeasurementVersion();
                break;
            case "queryLastMeasureECGData":
                queryLastMeasureECGData();
                break;
            case "sendECGHeartRate":
                sendECGHeartRate(call);
                break;
            case "sendWatchFaceBackground":
                sendWatchFaceBackground(call);
                break;
            //余诗霞:end

            //xulei:start
            case "sendDeviceLanguage":
                sendDeviceLanguage(call);
                break;
            case "queryDeviceLanguage":
                queryDeviceLanguage(result);
                break;
            case "sendOtherMessageState":
                sendOtherMessageState(call);
                break;
            case "queryOtherMessageState":
                queryOtherMessageState(result);
                break;
            case "sendMessage":
                sendMessage(call);
                break;
            case "sendCall0ffHook":
                sendCall0ffHook();
                break;
            case "sendSedentaryReminder":
                sendSedentaryReminder(call);
                break;
            case "querySedentaryReminderPeriod":
                querySedentaryReminderPeriod(result);
                break;
            case "sendSedentaryReminderPeriod":
                sendSedentaryReminderPeriod(call);
                break;
            case "querySedentaryReminder":
                querySedentaryReminder(result);
                break;
            case "findDevice":
                findDevice();
                break;
            case "shutDown":
                shutDown();
                break;
            case "sendDoNotDistrubTime":
                sendDoNotDistrubTime(call);
                break;
            case "queryDoNotDistrubTime":
                queryDoNotDistrubTime(result);
                break;
            case "sendBreathingLight":
                sendBreathingLight(call);
                break;
            case "queryBreathingLight":
                queryBreathingLight(result);
                break;
            //xulei:end
            // libaozhong: start
            case "sendPhysiologcalPeriod":
                sendPhysiologcalPeriod(call);
                break;
            case "queryPhysiologcalPeriod":
                queryPhysiologcalPeriod(result);
                break;
            case "startFindPhone":
                startFindPhone();
                break;
            case "stopFindPhone":
                stopFindPhone();
                break;
            case "setMusicPlayerState":
                setMusicPlayerState(call);
                break;
            case "sendSongTitle":
                sendSongTitle(call);
                break;
            case "sendLyrics":
                sendLyrics(call);
                break;
            case "closeMusicControl":
                closeMusicControl();
                break;
            case "sendCurrentVolume":
                sendCurrentVolume(call);
                break;
            case "sendMaxVolume":
                sendMaxVolume(call);
                break;
            case "enableDrinkWaterReminder":
                enableDrinkWaterReminder(call);
                break;
            case "disableDrinkWaterReminder":
                disableDrinkWaterReminder();
                break;
            case "queryDrinkWaterReminderPeriod":
                queryDrinkWaterReminderPeriod(result);
                break;
            case "setMaxHeartRate":
                setMaxHeartRate(call);
                break;
            case "queryMaxHeartRate":
                queryMaxHeartRate(result);
                break;
            case "startMovement":
                startMovement(call);
                break;
            case "setMovementState":
                setMovementState(call);
                break;
            case "getProtocolVersion":
                getProtocolVersion(result);
                break;
            case "startMeasureTemp":
                startMeasureTemp();
                break;
            case "stopMeasureTemp":
                stopMeasureTemp();
                break;
            case "enableTimingMeasureTemp":
                enableTimingMeasureTemp();
                break;
            case "disableTimingMeasureTemp":
                disableTimingMeasureTemp();
                break;
            case "queryTimingMeasureTempState":
                queryTimingMeasureTempState(result);
                break;
            case "queryTimingMeasureTemp":
                queryTimingMeasureTemp();
                break;
            case "sendDisplayTime":
                sendDisplayTime(call);
                break;
            case "queryDisplayTime":
                queryDisplayTime(result);
                break;
            case "enableHandWashingReminder":
                enableHandWashingReminder(call);
                break;
            case "disableHandWashingReminder":
                disableHandWashingReminder();
                break;
            case "queryHandWashingReminderPeriod":
                queryHandWashingReminderPeriod(result);
                break;
            case "sendLocalCity":
                sendLocalCity(call);
                break;
            case "sendTempUnit":
                sendTempUnit(call);
                break;
            case "queryTempUnit":
                queryTempUnit();
                break;
            case "sendBrightness":
                sendBrightness(call);
                break;
            case "queryBrightness":
                queryBrightness(result);
                break;
            case "queryBtAddress":
                queryBtAddress(result);
                break;
            case "checkSupportQuickContact":
                checkSupportQuickContact(result);
                break;
            case "queryContactCount":
                queryContactCount(result);
                break;
            case "sendContact":
                sendContact(call);
                break;
            case "deleteContact":
                deleteContact(call);
                break;
            case "queryBatterySaving":
                queryBatterySaving();
                break;
            case "sendBatterySaving":
                sendBatterySaving(call);
                break;
            case "queryPillReminder":
                queryPillReminder(result);
                break;
            case "sendPillReminder":
                sendPillReminder(call);
                break;
            case "deletePillReminder":
                deletePillReminder(call);
                break;
            case "clearPillReminder":
                clearPillReminder();
                break;
            case "queryTapToWakeState":
                queryTapToWakeState(result);
                break;
            case "sendTapToWakeState":
                sendTapToWakeState(call);
                break;
            case "queryHistoryTraining":
                queryHistoryTraining();
                break;
            case "queryTraining":
                queryTraining(call);
                break;
            // libaozhong: end
            default:
                result.notImplemented();

        }
    }

    // libaozhong: start
    private void queryTraining(MethodCall call) {
        Integer id = call.argument("id");
        id = id == null ? -1 : id;
        Log.d("---------",""+id);
        bleConnection.queryTraining(id);
    }

    private void queryHistoryTraining() {
        Log.d("---------", "----------");
        bleConnection.queryHistoryTraining();
    }

    private void sendTapToWakeState(MethodCall call) {
        Boolean enable = call.argument("enable");
        enable = enable != null && enable;
        Log.d("-----------", ""+enable);
        bleConnection.sendTapToWakeState(enable);
    }

    private void queryTapToWakeState(MethodChannel.Result result) {
        Log.d("-------", "-------");
        bleConnection.queryTapToWakeState(result::success);
    }

    private void clearPillReminder() {
        Log.d("-----------", "----------");
        bleConnection.clearPillReminder();
    }

    private void deletePillReminder(MethodCall call) {
        Integer id = call.argument("id");
        id = id == null ? -1 : id;
        Log.d("-------", ""+id);
        bleConnection.deletePillReminder(id);
    }

    private void sendPillReminder(MethodCall call) {
        String jsonStr = call.argument("pillReminderInfo");
        Log.d(TAG, jsonStr);
        CRPPillReminderInfo pillReminderInfo = GsonUtils.get().fromJson(jsonStr,
                CRPPillReminderInfo.class);
        Log.d("------", ""+pillReminderInfo);
        bleConnection.sendPillReminder(pillReminderInfo);
    }

    private void queryPillReminder(MethodChannel.Result result) {
        Log.d("-------", "--------");
        bleConnection.queryPillReminder((supportCount, list) -> {
            Log.d(TAG, supportCount + "");
            String jsonStr = GsonUtils.get().toJson(list, List.class);
            result.success(jsonStr);
        });
    }

    private void sendBatterySaving(MethodCall call) {
        Boolean enable = call.argument("enable");
        enable = enable != null && enable;
        Log.d("----------", ""+enable);
        bleConnection.sendBatterySaving(enable);
    }

    private void queryBatterySaving() {
        Log.d("-------", "---------");
        bleConnection.queryBatterySaving();
    }

    private void deleteContact(MethodCall call) {
        Integer id = call.argument("id");
        id = id == null ? -1 : id;
        Log.d("--------", id+"");
        bleConnection.deleteContact(id);
        bleConnection.deleteContactAvatar(id);
    }

    private void sendContactAvatar(MethodCall call) {
        BaseConnLazyEveChlHandler lazyEveChlHandler
                = connEveChlRegister.getLazyEveChlHandler(LAZY_EVE_CHL_CONN_CONTACT_AVATAR);
        if (lazyEveChlHandler == null) {
            return;
        }

        lazyEveChlHandler.setLazyConnListener(bleConnection, call);
    }

    private void sendContact(MethodCall call) {
        String jsonStr = call.argument("contactBean");
        Log.d(TAG, jsonStr);
        CRPContactBean contactBean = GsonUtils.get().fromJson(jsonStr,
                CRPContactBean.class);
        CRPContactInfo crpContactInfo = new CRPContactInfo(contactBean.getId(),
                contactBean.getWidth(),
                contactBean.getHeight(),
                contactBean.getAddress(),
                contactBean.getName(),
                contactBean.getNumber());
        Log.d("--------", ""+crpContactInfo);
        bleConnection.sendContact(crpContactInfo);
        sendContactAvatar(call);
    }

    private void queryContactCount(MethodChannel.Result result) {
        bleConnection.queryContactCount(result::success);
    }

    private void checkSupportQuickContact(MethodChannel.Result result) {
        bleConnection.checkSupportQuickContact(contactConfigInfo -> {
            String jsonStr = GsonUtils.get().toJson(contactConfigInfo);
            result.success(jsonStr);
        });
    }

    private void queryBtAddress(MethodChannel.Result result) {
        bleConnection.queryBtAddress(result::success);
    }

    private void queryBrightness(MethodChannel.Result result) {
        Log.d("-------","-------");
        bleConnection.queryBrightness((cuurent, max) -> {
            Map<String, Object> mapStr = new HashMap<>();
            mapStr.put("cuurent", cuurent);
            mapStr.put("max", max);
            result.success(mapStr);
        });
    }

    private void sendBrightness(MethodCall call) {
        Integer brightness = call.argument("brightness");
        brightness = brightness == null ? -1 : brightness;
        Log.d("---------", brightness+"");
        bleConnection.sendBrightness(brightness);
    }

    private void queryTempUnit() {
        Log.d("queryTempUnit----", "----");
        bleConnection.queryTempUnit();
    }

    private void sendTempUnit(MethodCall call) {
        Integer temp = call.argument("temp");
        temp = temp == null ? 1 : temp;
        Log.d("sendTempUnit-----", temp+"");
        bleConnection.sendTempUnit(temp.byteValue());
    }

    private void sendLocalCity(MethodCall call) {
        String city = call.argument("city");
        Log.d(TAG, city+"---");
        bleConnection.sendLocalCity(city);
    }

    private void queryHandWashingReminderPeriod(MethodChannel.Result result) {
        Log.d("----------", "---------");
        bleConnection.queryHandWashingReminderPeriod(info -> result.success(info.getPeriod()));
    }

    private void disableHandWashingReminder() {
        Log.d("-------", "--------");
        bleConnection.disableHandWashingReminder();
    }

    private void enableHandWashingReminder(MethodCall call) {
        String jsonStr = call.argument("handWashingPeriodInfo");
        Log.d(TAG, jsonStr);
        CRPHandWashingPeriodInfo handWashingPeriodInfo = GsonUtils.get().fromJson(jsonStr,
                CRPHandWashingPeriodInfo.class);
        bleConnection.enableHandWashingReminder(handWashingPeriodInfo);
    }

    private void queryDisplayTime(MethodChannel.Result result) {
        bleConnection.queryDisplayTime(time -> {
            Log.d(time+"", "----------239");
            result.success(time);
        });
    }

    private void sendDisplayTime(MethodCall call) {
        Integer time = call.argument("time");
        time = time == null ? -1 : time ;
        Log.d("-------",time+"");
        bleConnection.sendDisplayTime(time);
    }

    private void queryTimingMeasureTemp() {
        Log.d("queryTimingMeasureTemp-", "-----");
        bleConnection.queryTimingMeasureTemp(CRPTempTimeType.YESTERDAY);
    }

    private void queryTimingMeasureTempState(MethodChannel.Result result) {
        Log.d("------", "--------");
        bleConnection.queryTimingMeasureTempState(crpTimingTempState -> {
            Log.d("=========", "==========");
            String jsonStr = GsonUtils.get().toJson(crpTimingTempState);
            result.success(jsonStr);
        });
    }

    private void disableTimingMeasureTemp() {
        Log.d("------", "-------");
        bleConnection.disableTimingMeasureTemp();
    }

    private void enableTimingMeasureTemp() {
        Log.d("enableTimingMeasureTemp", "-------");
        bleConnection.enableTimingMeasureTemp();
    }

    private void stopMeasureTemp() {
        Log.d("stopMeasureTemp-----", "-----");
        bleConnection.stopMeasureTemp();
    }

    private void startMeasureTemp() {
        Log.d("startMeasureTemp----", "------");
        bleConnection.startMeasureTemp();
    }

    private void setMovementState(MethodCall call) {
        Byte type = call.argument("type");
        type = type == null ? -1 : type;
        Log.d("---------", ""+type);
        bleConnection.setMovementState(type);
    }

    private void startMovement(MethodCall call) {
        Byte type = call.argument("type");
        type = type == null ? -1 : type;
        Log.d("------", ""+type);
        bleConnection.startMovement(type);
    }

    private void queryMaxHeartRate(MethodChannel.Result result) {
        Log.d("queryMaxHeartRate----", "------");
        bleConnection.queryMaxHeartRate((heartRate, enable) -> {
            ConstraintsMap paramsMap = new ConstraintsMap();
            paramsMap.putInt("heartRate", heartRate);
            paramsMap.putBoolean("enable", enable);
            result.success(paramsMap.toMap());
        });
    }

    private void setMaxHeartRate(MethodCall call) {
        Byte heartRate = call.argument("heartRate");
        Boolean enable = call.argument("enable");
        heartRate = heartRate == null ? -1 : heartRate;
        enable = enable != null && enable;
        Log.d("----"+heartRate, "----"+enable);
        bleConnection.setMaxHeartRate(heartRate, enable);
    }

    private void queryDrinkWaterReminderPeriod(MethodChannel.Result result) {
        bleConnection.queryDrinkWaterReminderPeriod(drinkWaterPeriodInfo -> {
            String jsonStr = GsonUtils.get().toJson(drinkWaterPeriodInfo);
            result.success(jsonStr);
        });
    }

    private void disableDrinkWaterReminder() {
        Log.d(TAG, "-----");
        bleConnection.disableDrinkWaterReminder();
    }

    private void enableDrinkWaterReminder(MethodCall call) {
        String jsonStr = call.argument("drinkWaterPeriodInfo");
        Log.d(TAG, jsonStr);
        CRPDrinkWaterPeriodInfo drinkWaterPeriodInfo = GsonUtils.get().fromJson(jsonStr,
                CRPDrinkWaterPeriodInfo.class);
        Log.d(TAG, drinkWaterPeriodInfo+"");
        bleConnection.enableDrinkWaterReminder(drinkWaterPeriodInfo);
    }

    private void sendMaxVolume(MethodCall call) {
        Integer volume = call.argument("volume");
        volume = volume == null ? -1 : volume;
        Log.d("--------", volume+"");
        bleConnection.sendMaxVolume(volume);
    }

    private void sendCurrentVolume(MethodCall call) {
        Integer volume = call.argument("volume");
        volume = volume == null ? -1 : volume;
        Log.d("--------", volume+"");
        bleConnection.sendCurrentVolume(volume);
    }

    private void closeMusicControl() {
        Log.d("---------", "------");
        bleConnection.closeMusicControl();
    }

    private void sendLyrics(MethodCall call) {
        Log.d(TAG, "-----"+call.argument("lyrics"));
        bleConnection.sendLyrics(call.argument("lyrics"));
    }

    private void sendSongTitle(MethodCall call) {
        Log.d(call.argument("title") + "", "======");
        bleConnection.sendSongTitle(call.argument("title"));
    }

    private void setMusicPlayerState(MethodCall call) {
        byte type = call.argument("CRPMusicPlayerStateType") == "1" ?
                CRPMusicPlayerStateType.MUSIC_PLAYER_PAUSE :
                CRPMusicPlayerStateType.MUSIC_PLAYER_PLAY;
        Log.d("setMusicPlayerState--", ""+type);
        bleConnection.setMusicPlayerState(type);
    }

    private void stopFindPhone() {
        Log.d(TAG, "-------");
        bleConnection.stopFindPhone();
    }

    private void startFindPhone() {
        Log.d("3333", "====");
        bleConnection.startFindPhone();
    }

    private void sendPhysiologcalPeriod(MethodCall call) {
        String jsonStr = call.argument("futureWeatherInfo");
        Log.d(TAG, jsonStr);
        CRPPhysiologcalPeriodInfo crpPhysiologcalPeriodInfo = GsonUtils.get().fromJson(jsonStr,
                CRPPhysiologcalPeriodInfo.class);
        Log.d(TAG, crpPhysiologcalPeriodInfo+"");
        bleConnection.sendPhysiologcalPeriod(crpPhysiologcalPeriodInfo);
    }

    private void queryPhysiologcalPeriod(MethodChannel.Result result) {
        bleConnection.queryPhysiologcalPeriod(crpPhysiologcalPeriodInfo -> {
            String jsonStr = GsonUtils.get().toJson(
                    crpPhysiologcalPeriodInfo.getPhysiologcalPeriod());
            result.success(jsonStr);
        });
    }

    private void getProtocolVersion(MethodChannel.Result result) {
        String jsonStr = GsonUtils.get().toJson(bleConnection.getProtocolVersion());
        Log.d("------", jsonStr+"");
        result.success(jsonStr);
    }
    // libaozhong: end

    private void sendFutureWeather(MethodCall call) {
        String jsonStr = call.argument("futureWeatherInfo");
        Log.d(TAG, jsonStr);
        CRPFutureWeatherInfo futureWeatherInfo = GsonUtils.get().fromJson(jsonStr,
                CRPFutureWeatherInfo.class);
        bleConnection.sendFutureWeather(futureWeatherInfo);
    }

    private void sendTodayWeather(MethodCall call) {
        String jsonStr = call.argument("todayWeatherInfo");
        Log.d(TAG, jsonStr);
        CRPTodayWeatherInfo todayWeatherInfo = GsonUtils.get().fromJson(jsonStr,
                CRPTodayWeatherInfo.class);
        bleConnection.sendTodayWeather(todayWeatherInfo);
    }

    private void sendStepLength(MethodCall call) {
        Integer stepLength = call.argument("stepLength");
        stepLength = stepLength == null ? -1 : stepLength;
        bleConnection.sendStepLength(stepLength.byteValue());
    }

    private void sendUserInfo(MethodCall call) {
        String jsonStr = call.argument("userInfo");
        Log.d(TAG, jsonStr);
        CRPUserInfo userInfo = GsonUtils.get().fromJson(jsonStr, CRPUserInfo.class);
        bleConnection.sendUserInfo(userInfo);
    }

    private void sendTimeSystem(@NonNull MethodCall call) {
        Integer timeSystemType = call.argument("timeSystemType");
        timeSystemType = timeSystemType == null ? CRPTimeSystemType.TIME_SYSTEM_12 : timeSystemType;

        bleConnection.sendTimeSystem(timeSystemType.byteValue());
    }

    private void queryTimeSystem(MethodChannel.Result result) {
        bleConnection.queryTimeSystem(result::success);
    }

    private void queryDeviceBattery() {//调用该方法，电量值会在CRPDeviceBatteryListener中回调
        bleConnection.queryDeviceBattery();
    }

    private void subscribeDeviceBattery() {
        bleConnection.subscribeDeviceBattery();
    }

    private void queryFirmwareVersion(MethodChannel.Result result) {
        bleConnection.queryFrimwareVersion(result::success);
    }

    private void checkFirmwareVersion(MethodCall call, MethodChannel.Result result) {
        String version = call.argument("version");
        if (bleConnection == null) {
            result.success(null);
            return;
        }

        bleConnection.checkFirmwareVersion(new CRPDeviceNewFirmwareVersionCallback() {
            @Override
            public void onNewFirmwareVersion(CRPFirmwareVersionInfo crpFirmwareVersionInfo) {
                String jsonStr = GsonUtils.get().toJson(crpFirmwareVersionInfo);
                result.success(jsonStr);
            }

            @Override
            public void onLatestVersion() {
                result.success(null);
            }
        }, version, CRPFirmwareUpgradeType.NORMAL_UPGEADE_TYPE);

        //TODO 临时调试用，后面需要删掉（上面两个方法都没有回调，原因未知）
        CRPFirmwareVersionInfo versionInfo = new CRPFirmwareVersionInfo(
                "aaa", "bbb", "ccc", 11, 22, true);
        String jsonStr = GsonUtils.get().toJson(versionInfo);
        result.success(jsonStr);
    }

    private void isConnected(MethodCall call, MethodChannel.Result result) {
        String address = call.argument("address");
        result.success(isConnected(address));
    }

    private boolean isConnected(String address) {
        CRPBleDevice mBleDevice = bleClient.getBleDevice(address);
        return mBleDevice != null && mBleDevice.isConnected();
    }

    private boolean checkBluetoothEnable() {
        if (!bleClient.isBluetoothEnable()) {
            Intent enableBtIntent = new Intent(BluetoothAdapter.ACTION_REQUEST_ENABLE);
            activity.startActivity(enableBtIntent);
        }

        return bleClient.isBluetoothEnable();
    }

    private void closeGatt(MethodChannel.Result result) {
        if (bleConnection != null) {
            bleConnection.close();
            bleConnection = null;
            result.success(true);
        }
    }

    //余诗霞:start
    private void queryMetricSystem(MethodChannel.Result result) {
        bleConnection.queryMetricSystem(result::success);
    }

    private void sendMetricSystem(MethodCall call) {
        Integer metricSystemType = call.argument("metricSystemType");
        metricSystemType = metricSystemType == null ?
                CRPMetricSystemType.METRIC_SYSTEM : metricSystemType;

        bleConnection.sendMetricSystem(metricSystemType.byteValue());
    }

    private void sendQuickView(MethodCall call) {
        Boolean quickViewState = call.argument("quickViewState");
        quickViewState = quickViewState != null && quickViewState;

        bleConnection.sendQuickView(quickViewState);
    }

    private void queryQuickView(MethodChannel.Result result) {
        bleConnection.queryQuickView(result::success);
    }

    private void sendQuickViewTime(MethodCall call) {
        String jsonStr = call.argument("periodTimeInfo");
        Log.d(TAG, jsonStr);
        CRPPeriodTimeInfo periodTimeInfo = GsonUtils.get().fromJson(jsonStr,
                CRPPeriodTimeInfo.class);

        bleConnection.sendQuickViewTime(periodTimeInfo);
    }

    private void queryQuickViewTime(MethodChannel.Result result) {
        bleConnection.queryQuickViewTime((i, crpPeriodTimeInfo) -> {
            String jsonStr = GsonUtils.get().toJson(crpPeriodTimeInfo, CRPPeriodTimeInfo.class);
            Map<String, Object> mapStr = new HashMap<>();
            mapStr.put("i", i);
            mapStr.put("CRPPeriodTimeInfo", jsonStr);
            Log.d(TAG, "queryQuickViewTime: " + jsonStr);
            result.success(mapStr);
        });
    }

    private void sendGoalSteps(MethodCall call) {
        Integer goalSteps = call.argument("goalSteps");
        goalSteps = goalSteps == null ? 8000 : goalSteps;

        bleConnection.sendGoalSteps(goalSteps);
    }

    private void queryGoalStep(MethodChannel.Result result) {
        bleConnection.queryGoalStep(result::success);
    }

    private void sendDisplayWatchFace(MethodCall call) {
        Integer watchFaceType = call.argument("watchFaceType");
        watchFaceType = watchFaceType == null ? CRPWatchFaceType.FIRST_WATCH_FACE : watchFaceType;

        bleConnection.sendDisplayWatchFace(watchFaceType.byteValue());
    }

    private void queryDisplayWatchFace(MethodChannel.Result result) {
        bleConnection.queryDisplayWatchFace(result::success);
    }

    private void queryWatchFaceLayout(MethodChannel.Result result) {
        bleConnection.queryWatchFaceLayout(crpWatchFaceLayoutInfo -> {
            String jsonStr = GsonUtils.get().toJson(crpWatchFaceLayoutInfo, CRPWatchFaceLayoutInfo.class);
            result.success(jsonStr);
        });
    }

    private void sendWatchFaceLayout(MethodCall call) {
        String jsonStr = call.argument("watchFaceLayoutInfo");
        Log.d(TAG, jsonStr);
        CRPWatchFaceLayoutInfo watchFaceLayoutInfo = GsonUtils.get().fromJson(jsonStr, CRPWatchFaceLayoutInfo.class);

        bleConnection.sendWatchFaceLayout(watchFaceLayoutInfo);
    }

    private void sendWatchFaceBackground(MethodCall call) {
        BaseConnLazyEveChlHandler lazyEveChlHandler
                = connEveChlRegister.getLazyEveChlHandler(LAZY_EVE_CHL_CONN_FILE_TRANS);
        if (lazyEveChlHandler == null) {
            return;
        }

        lazyEveChlHandler.setLazyConnListener(bleConnection, call);
    }

    private void querySupportWatchFace(MethodChannel.Result result) {
        bleConnection.querySupportWatchFace(crpSupportWatchFaceInfo -> {
            String jsonStr = GsonUtils.get().toJson(crpSupportWatchFaceInfo, CRPSupportWatchFaceInfo.class);
            result.success(jsonStr);
        });
    }

    private void queryWatchFaceStore(MethodCall call, MethodChannel.Result result) {
        String jsonStr = call.argument("watchFaceStoreBean");
        Log.d(TAG, jsonStr);
        WatchFaceStoreBean watchFaceLayoutInfo = GsonUtils.get().fromJson(jsonStr, WatchFaceStoreBean.class);
        Log.d("------",""+watchFaceLayoutInfo.getWatchFaceSupportList());
        Log.d("------",""+watchFaceLayoutInfo.getFirmwareVersion());

        Map<String, Object> mapStr = new HashMap<>();
        bleConnection.queryWatchFaceStore(watchFaceLayoutInfo.getWatchFaceSupportList(), watchFaceLayoutInfo.getFirmwareVersion(),
                watchFaceLayoutInfo.getPageCount(), watchFaceLayoutInfo.getPageIndex(), new CRPDeviceWatchFaceStoreCallback() {
                    @Override
                    public void onWatchFaceStoreChange(CRPWatchFaceInfo crpWatchFaceInfo) {
                        String jsonStr = GsonUtils.get().toJson(crpWatchFaceInfo, CRPWatchFaceInfo.class);
                        mapStr.put("isError", false);
                        mapStr.put("WatchFaceStore", jsonStr);
                        result.success(mapStr);
                    }

                    @Override
                    public void onError(String s) {
                        mapStr.put("isError", true);
                        mapStr.put("error", s);
                        result.success(mapStr);
                    }
                });
    }

    private void queryWatchFaceOfID(MethodCall call, MethodChannel.Result result) {
        Integer id = call.argument("id");
        id = id == null ? -1: id;
        Map<String, Object> mapStr = new HashMap<>();
        bleConnection.queryWatchFaceOfID(id, new CRPDeviceWatchFaceCallback() {
            @Override
            public void onWatchFaceChange(CRPWatchFaceInfo.WatchFaceBean watchFaceBean) {
                String jsonStr = GsonUtils.get().toJson(watchFaceBean, CRPWatchFaceInfo.WatchFaceBean.class);
                mapStr.put("isError", true);
                mapStr.put("watchFaceBean", jsonStr);
                result.success(mapStr);
            }

            @Override
            public void onError(String s) {
                mapStr.put("isError", true);
                mapStr.put("error", s);
                result.success(mapStr);
            }
        });
    }

    private void sendWatchFace(MethodCall call) {
        BaseConnLazyEveChlHandler lazyEveChlHandler
                = connEveChlRegister.getLazyEveChlHandler(LAZY_EVE_CHL_CONN_WF_FILE_TRANS);
        if (lazyEveChlHandler == null) {
            return;
        }

        lazyEveChlHandler.setLazyConnListener(bleConnection, call);
    }

    private void sendAlarmClock(MethodCall call) {
        String jsonStr = call.argument("alarmClockInfo");
        Log.d(TAG, jsonStr);
        CRPAlarmClockInfo crpAlarmClockInfo = GsonUtils.get().fromJson(jsonStr, CRPAlarmClockInfo.class);

        bleConnection.sendAlarmClock(crpAlarmClockInfo);
    }

    private void queryAllAlarmClock(MethodChannel.Result result) {
        bleConnection.queryAllAlarmClock(list -> {
            List<String> jsonStr = new ArrayList<>();
            for (int i = 0; i < list.size(); i++) {
                jsonStr.add(GsonUtils.get().toJson(list.get(i), CRPAlarmClockInfo.class));
            }
            result.success(jsonStr.toString());
        });
    }
    //心率
    private void queryLastDynamicRate() {
        bleConnection.queryLastDynamicRate(CRPHistoryDynamicRateType.FIRST_HEART_RATE);
    }

    private void enableTimingMeasureHeartRate(MethodCall call) {
        Integer interval = call.argument("interval");
        interval = interval == null ? 2 : interval;
        Log.d("--------", ""+interval);
        bleConnection.enableTimingMeasureHeartRate(interval);
    }

    private void disableTimingMeasureHeartRate() {
        Log.d("----", "---");
        bleConnection.disableTimingMeasureHeartRate();
    }

    private void queryTimingMeasureHeartRate(MethodChannel.Result result) {
        bleConnection.queryTimingMeasureHeartRate(result::success);
    }

    private void queryTodayHeartRate(MethodCall call) {
        Integer heartRateType = call.argument("heartRateType");
        heartRateType = heartRateType == null ? CRPHeartRateType.ALL_DAY_HEART_RATE : heartRateType;
        Log.d("------", heartRateType+"");
        bleConnection.queryTodayHeartRate(heartRateType);
    }

    private void queryPastHeartRate() {
        Log.d("------", "-------");
        bleConnection.queryPastHeartRate();
    }

    private void queryMovementHeartRate() {
        Log.d("------", "-------");
        bleConnection.queryMovementHeartRate();
    }

    private void startMeasureOnceHeartRate() {
        Log.d("------", "-------");
        bleConnection.startMeasureOnceHeartRate();
    }

    private void stopMeasureOnceHeartRate() {
        Log.d("------", "-------");
        bleConnection.stopMeasureOnceHeartRate();
    }

    private void queryHistoryHeartRate() {
        Log.d("------", "-------");
        bleConnection.queryHistoryHeartRate();
    }

    //血压
    private void startMeasureBloodPressure() {
        Log.d("------", "-------");
        bleConnection.startMeasureBloodPressure();
    }

    private void stopMeasureBloodPressure() {
        Log.d("------", "-------");
        bleConnection.stopMeasureBloodPressure();
    }

    private void enableContinueBloodPressure() {
        Log.d("-----", "-----");
        bleConnection.enableContinueBloodPressure();
    }

    private void disableContinueBloodPressure() {
        Log.d("-----", "-----");
        bleConnection.disableContinueBloodPressure();
    }

    private void queryContinueBloodPressureState() {
        Log.d("-----", "-----");
        bleConnection.queryContinueBloodPressureState();
    }

    private void queryLast24HourBloodPressure() {
        Log.d("-----", "-----");
        bleConnection.queryLast24HourBloodPressure();
    }

    private void queryHistoryBloodPressure() {
        Log.d("-----", "-----");
        bleConnection.queryHistoryBloodPressure();
    }

    //血氧
    private void startMeasureBloodOxygen() {
        Log.d("-----", "-----");
        bleConnection.startMeasureBloodOxygen();
    }

    private void stopMeasureBloodOxygen() {
        Log.d("-----", "-----");
        bleConnection.stopMeasureBloodOxygen();
    }

    private void enableTimingMeasureBloodOxygen(MethodCall call) {
        Integer interval = call.argument("interval");
        interval = interval == null ? 5 : interval;
        Log.d("-----", ""+interval);
        bleConnection.enableTimingMeasureBloodOxygen(interval);
    }

    private void disableTimingMeasureBloodOxygen() {
        Log.d("-----", "-----");
        bleConnection.disableTimingMeasureBloodOxygen();
    }

    private void queryTimingBloodOxygenMeasureState() {
        Log.d("-----", "-----");
        bleConnection.queryTimingBloodOxygenMeasureState();
    }

    private void queryTimingBloodOxygen(MethodCall call) {
        String bloodOxygenTimeType = call.argument("bloodOxygenTimeType");
        bloodOxygenTimeType = bloodOxygenTimeType == null ? CRPBloodOxygenTimeType.TODAY.toString() : bloodOxygenTimeType;
        Log.d("------",bloodOxygenTimeType);
        bleConnection.queryTimingBloodOxygen(CRPBloodOxygenTimeType.valueOf(bloodOxygenTimeType));
    }

    private void enableContinueBloodOxygen() {
        Log.d("-----", "-----");
        bleConnection.enableContinueBloodOxygen();
    }

    private void disableContinueBloodOxygen() {
        Log.d("-----", "-----");
        bleConnection.disableContinueBloodOxygen();
    }

    private void queryContinueBloodOxygenState() {
        Log.d("-----", "-----");
        bleConnection.queryContinueBloodOxygenState();
    }


    private void queryLast24HourBloodOxygen() {
        Log.d("-----", "-----");
        bleConnection.queryLast24HourBloodOxygen();
    }

    private void queryHistoryBloodOxygen() {
        Log.d("-----", "-----");
        bleConnection.queryHistoryBloodOxygen();
    }

    //拍照
    private void enterCameraView() {
        Log.d("-----", "-----");
        bleConnection.enterCameraView();
    }

    private void exitCameraView() {
        Log.d("-----", "-----");
        bleConnection.exitCameraView();
    }

    //rssi
    private void readDeviceRssi() {
        Log.d("-----", "-----");
        bleConnection.readDeviceRssi();
    }

    //egc
    private void setECGChangeListener(MethodCall call) {
        BaseConnLazyEveChlHandler lazyEveChlHandler
                = connEveChlRegister.getLazyEveChlHandler(LAZY_EVE_CHL_CONN_EGC);
        if (lazyEveChlHandler == null) {
            return;
        }
        Log.d(TAG, "setECGChangeListener: ====");
        lazyEveChlHandler.setLazyConnListener(bleConnection, call);
    }

    private void startECGMeasure() {
        Log.d("-----", "-----");
        bleConnection.startECGMeasure();
    }

    private void stopECGMeasure() {
        Log.d("-----", "-----");
        bleConnection.stopECGMeasure();
    }

    private void isNewECGMeasurementVersion() {
        boolean newMeasurementVersion = bleConnection.isNewECGMeasurementVersion();
        Log.d(TAG, "isNewECGMeasurementVersion: " + newMeasurementVersion);
    }

    private void queryLastMeasureECGData() {
        Log.d("-----", "-----");
        bleConnection.queryLastMeasureECGData();
    }

    private void sendECGHeartRate(MethodCall call) {
        Integer heartRate = call.argument("heartRate");
        heartRate = heartRate == null ? 0 : heartRate;
        Log.d("sendECGHeartRate-----", ""+heartRate);
        bleConnection.sendECGHeartRate(heartRate);
    }
    //余诗霞::end

    //xulei:start
    //2.17 Language
    private void sendDeviceLanguage(MethodCall call){
        Integer language = call.argument("language");
        language = language == null ? CRPDeviceLanguageType.LANGUAGE_CHINESE : language;
        // 简体中文设置为中文版，非简体中文设置为国际版
        byte version = CRPDeviceVersionType.INTERNATIONAL_EDITION;
        if (language == CRPDeviceLanguageType.LANGUAGE_CHINESE) {
            version = CRPDeviceVersionType.CHINESE_EDITION;
        }
        Log.d("--------",""+version);
        Log.d("---------", ""+language.byteValue());
        bleConnection.sendDeviceVersion(version);
        bleConnection.sendDeviceLanguage(language.byteValue());
    }

    private void queryDeviceLanguage(MethodChannel.Result result){
        bleConnection.queryDeviceLanguage((i, ints) -> {
            Log.d(TAG, "onDeviceLanguage: --------");
//                String jsonStr = GsonUtils.get().toJson(crpPeriodTimeInfo, CRPPeriodTimeInfo.class);
            Map<String,String > mapStr=new HashMap<>();
            mapStr.put("i",i+"");
            mapStr.put("type",ints.toString());
            Log.d(TAG, "queryDeviceLanguage: "+mapStr);
            result.success(mapStr);
        });
    }
    //2.18 Notification
    //打开或关闭其他消息
    private void sendOtherMessageState(MethodCall call){
        Boolean messageState = call.argument("messageState");
        messageState =   messageState != null && messageState;
        Log.d("------", ""+messageState);
        bleConnection.sendOtherMessageState(messageState);
    }
    //查询其他消息启用状态
    private void queryOtherMessageState(MethodChannel.Result result){
        bleConnection.queryOtherMessageState(result::success);
    }
    //向手表发送各种类型的消息内容
    private void sendMessage(MethodCall call){
        String jsonStr = call.argument("messageInfo");
        Log.d(TAG, jsonStr);
        CRPMessageInfo messageInfo = GsonUtils.get().fromJson(jsonStr, CRPMessageInfo.class);
        bleConnection.sendMessage(messageInfo);
    }
    //当手表连接或手机挂断时，呼叫此接口停止手表振动 -------有问题
    private void sendCall0ffHook(){
        Log.d("---sendCall0ffHook:---", "----");
        bleConnection.sendCall0ffHook();
    }

    //2.19 Sedentary reminder
    //久坐不动的提醒器是否打开
    private void sendSedentaryReminder(MethodCall call){
        Boolean sedentaryReminder = call.argument("sedentaryReminder");
        sedentaryReminder =   sedentaryReminder != null && sedentaryReminder;
        Log.d("-----",""+sedentaryReminder);
        bleConnection.sendSedentaryReminder(sedentaryReminder);
    }
    //查询久坐提醒器状态
    private void querySedentaryReminder(MethodChannel.Result result){
        bleConnection.querySedentaryReminder(new CRPDeviceSedentaryReminderCallback() {
            @Override
            public void onSedentaryReminder(boolean b) {
                result.success(b);
            }
        });
    }
    //设置久坐提醒的有效期
    private void sendSedentaryReminderPeriod(MethodCall call){
        String jsonStr = call.argument("crpSedentaryReminderPeriodInfo");
        Log.d(TAG, jsonStr);
        CRPSedentaryReminderPeriodInfo sedentaryReminderPeriodInfo =
                GsonUtils.get().fromJson(jsonStr, CRPSedentaryReminderPeriodInfo.class);
        bleConnection.sendSedentaryReminderPeriod(sedentaryReminderPeriodInfo);
    }
    //获得久坐不动的提醒时间
    private void querySedentaryReminderPeriod(MethodChannel.Result result){
        bleConnection.querySedentaryReminderPeriod(new CRPDeviceSedentaryReminderPeriodCallback() {
            @Override
            public void onSedentaryReminderPeriod(CRPSedentaryReminderPeriodInfo crpSedentaryReminderPeriodInfo) {
                String jsonStr = GsonUtils.get().toJson(crpSedentaryReminderPeriodInfo, CRPSedentaryReminderPeriodInfo.class);
                result.success(jsonStr);
            }
        });
    }
    //2.20 寻找手表，在收到这个命令后，手表会振动几秒钟
    private void findDevice(){
        Log.d("findDevice------", "----");
        bleConnection.findDevice();
    }
    //2.27 Shut down 手表关机
    private void shutDown(){
        Log.d("shutDown------", "------");
        bleConnection.shutDown();
    }
    //2.28 免打扰
    private void sendDoNotDistrubTime(MethodCall call){
        String jsonStr = call.argument("crpPeriodTimeInfo");
        Log.d(TAG, jsonStr);
        CRPPeriodTimeInfo crpPeriodTimeInfo =
                GsonUtils.get().fromJson(jsonStr, CRPPeriodTimeInfo.class);
        bleConnection.sendDoNotDistrubTime(crpPeriodTimeInfo);
    }
    private void queryDoNotDistrubTime(MethodChannel.Result result){
        Log.d("-----", "----");
       bleConnection.queryDoNotDistrubTime((i, periodTimeInfo) -> {
           String jsonStr = GsonUtils.get().toJson(periodTimeInfo, CRPPeriodTimeInfo.class);
           Map<String,String> periodTime = new HashMap<>();
           periodTime.put("type",i+"");
           periodTime.put("crpPeriodTimeInfo",jsonStr);
           Log.d(TAG, "onPeriodTime: " + periodTime);
           result.success(periodTime);
       });
    }
    //2.29 呼吸灯
    // 呼吸灯是否打开
    private void sendBreathingLight(MethodCall call){
        Boolean breathingLight = call.argument("breathingLight");
        breathingLight =   breathingLight != null && breathingLight;
        Log.d("sendBreathingLight-----", ""+breathingLight);
        bleConnection.sendBreathingLight(breathingLight);
    }
    private void queryBreathingLight(MethodChannel.Result result){
        Log.d("queryBreathingLight---", "-----");
        bleConnection.queryBreathingLight(new CRPDeviceBreathingLightCallback() {
            @Override
            public void onBreathingLight(boolean b) {
                result.success(b);
            }
        });
    }
    //xulei:end
}
