//
//  FlutterBlueToothPlugin.swift
//  Runner
//
//  Created by 魔样科技 on 2022/5/14.
//

import Foundation
import Flutter
import CRPSmartBand

class FlutterBlueToothPlugin: NSObject {

    // 唯一通道标识
       static let CHANNEL_NAME: String = "method_chl_ble_scan"

}

extension FlutterBlueToothPlugin: FlutterPlugin {
    //实现注册函数
    static func register(with registrar: FlutterPluginRegistrar) {
        //方法的通道
        let channel = FlutterMethodChannel(name: CHANNEL_NAME, binaryMessenger: registrar.messenger())
        //创建类对象
        let myBlueTooth = FlutterBlueToothPlugin()
        //添加注册
        registrar.addMethodCallDelegate(myBlueTooth, channel: channel)
    }

    //实现flutter调用
    func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
        var message: String?
        if let args = call.arguments as? Dictionary<String, Any?> {
            message = args["message"] as? String
        }
        print("flutter发送过来的是：\(call.method)")
        if call.method == "startScan" {
            //开始扫描
            NKBluetoothManager.shared.startScan(10) { discoverys in

            } completionHandler: { discoverys, error in

            }

        }

        else if call.method == "cancelScan" {
            //取消扫描
            NKBluetoothManager.shared.stopScan()
        }
        else if call.method == "isConnected" {
            print("address:\(message)")
        }
        else if call.method == "connect" {
            print("address:\(message)")
        }
        else if call.method == "disconnect" {
            //断开连接
            NKBluetoothManager.shared.dicConnect()
        }
        //MARK: - 同步时间 -
        else if call.method == "syncTime" {
            //同步时间
            NKBluetoothManager.shared.setTime()
        }
        //MARK: - 设置时间制式 -
        else if call.method == "timeSystemType" {
            //设置时间制
            NKBluetoothManager.shared.setTimeFormat(message as! Int)
        }
        else if call.method == "queryTimeSystem" {
            //查询时间制式
            NKBluetoothManager.shared.getTimeformat { formatType in
                result("要传给Flutter的数据")
            }
        }
        //MARK: - 查询手环电量 -
        else if call.method == "queryDeviceBattery" {
            //查询手环电量
            NKBluetoothManager.shared.getBattery { battery in
                result("要传给Flutter的数据")
            }
        }
        else if call.method == "subscribeDeviceBattery" {
            //订阅手环电量
        }
        //MARK: - 固件升级 -
        else if call.method == "queryFirmwareVersion" {
            //查询固件版本
            NKBluetoothManager.shared.getSoftver { softver in
                result("要传给Flutter的数据")
            }
        }
        else if call.method == "checkFirmwareVersion" {
            //查询新固件
            NKBluetoothManager.shared.checkLatest("", "") { newVersionInfo, newVersionTpInfo in
                result("要传给Flutter的数据")
            }
        }
        //MARK: - 用户信息 -
        else if call.method == "sendUserInfo" {
            //设置⽤户信息
            NKBluetoothManager.shared.setProfile(ProfileModel())
        }
        else if call.method == "sendStepLength" {
            //设置步⻓
            NKBluetoothManager.shared.setStepLength(length: 10)
        }
        //MARK: - 天气 -
        else if call.method == "sendTodayWeather" {
            //设置今⽇天⽓
            NKBluetoothManager.shared.setWeather(CRPSmartBand.weather())
        }
        else if call.method == "sendFutureWeather" {
            //设置未来7⽇天⽓
            NKBluetoothManager.shared.setForecastWeather([forecastWeather()])
        }
        else if call.method == "sendLocalCity" {
            //设置本地城市
            NKBluetoothManager.shared.sendCityName("")
        }
        //MARK: - 体温 -
        else if call.method == "queryMetricSystem" {
            //获取体温单位
            NKBluetoothManager.shared.getTemperatureUnit { temperature, error in
                result("要传给Flutter的数据")
            }
        }
        else if call.method == "sendMetricSystem" {
            //设置体温单位
            NKBluetoothManager.shared.setTemperatureUnit(0)
        }
        //MARK: - 翻腕亮屏 -
        else if call.method == "sendQuickView" {
            //设置翻腕亮屏状态
            NKBluetoothManager.shared.setQuickView(Bool())
        }
        else if call.method == "queryQuickView" {
            //查询⼿环翻腕亮屏开启状态,0: 关闭 1： 开启
            NKBluetoothManager.shared.getQuickView { state, error in
                result("要传给Flutter的数据")
            }
        }
        else if call.method == "sendQuickViewTime" {
            //设置翻腕亮屏时间
            NKBluetoothManager.shared.setQuickViewTime(periodTimeModel())
        }
        else if call.method == "queryQuickViewTime" {
            //获取翻腕亮屏时间
            NKBluetoothManager.shared.getQuickViewTime { model, error in
                result("要传给Flutter的数据")
            }
        }
        //MARK: - 目标步数 -
        else if call.method == "sendGoalSteps" {
            //设置目标步数
            NKBluetoothManager.shared.setGoal(1)
        }
        else if call.method == "queryGoalStep" {
            //查询⽬标步数
            NKBluetoothManager.shared.getGoal { goal in
                result("要传给Flutter的数据")
            }
        }
        //MARK: - 表盘 -
        else if call.method == "sendDisplayWatchFace" {
            //切换⼿环表盘
            NKBluetoothManager.shared.setDial(0)
        }
        else if call.method == "queryDisplayWatchFace" {
            //查询⼿环正在使⽤的表盘序号
            NKBluetoothManager.shared.getDial { number, error in
                result("要传给Flutter的数据")
            }
        }
        else if call.method == "queryWatchFaceLayout" {
            //获取指定表盘布局
            NKBluetoothManager.shared.getScreenContent { content, imageSize, i, error in
                result("要传给Flutter的数据")
            }
        }
        else if call.method == "sendWatchFaceLayout" {
            //修改⾃定义表盘布局
            NKBluetoothManager.shared.setupScreenContent(content: ScreenContent())
        }
        else if call.method == "querySupportWatchFace" {
            //获取⽀持摆盘类型
            NKBluetoothManager.shared.getWatchFaceSupportModel { model, error in
                result("要传给Flutter的数据")
            }
        }
        else if call.method == "queryWatchFaceStore" {
            //获取表盘市场,根据表盘的⽀持类型获取能可以更换的表盘列表(分⻚获取)
            NKBluetoothManager.shared.getWatchFaceInfo([1,2], currentPage: 1, perPage: 18) { datas, currentPage, perPage, error in
                result("要传给Flutter的数据")
            }
        }
        else if call.method == "queryWatchFaceOfID" {
            //获取表盘ID的表盘信息
            NKBluetoothManager.shared.getWatchFaceInfoByID(0) { datas, currentPage, perPage, error in
                result("要传给Flutter的数据")
            }
        }
        
        //MARK: - 闹钟 -
        else if call.method == "sendAlarmClock" {
            //设置手环闹钟
            NKBluetoothManager.shared.setAlarm(alarm: AlarmModel())
        }
        else if call.method == "queryAllAlarmClock" {
            //查询所有闹钟
            NKBluetoothManager.shared.getAlarms { alarms in
                result("要传给Flutter的数据")
            }
        }
        //MARK: - 心率 -
        else if call.method == "queryLastDynamicRate" {
            //查询上次动态⼼率测量结果,receiveHeartRateAll回调
            NKBluetoothManager.shared.getHeartData()
        }
        else if call.method == "enableTimingMeasureHeartRate" {
            //开始定时测量心率，正数为开启
            NKBluetoothManager.shared.set24HourHeartRate(1)
        }
        else if call.method == "disableTimingMeasureHeartRate" {
            //关闭定时测量心率，0为关闭
            NKBluetoothManager.shared.set24HourHeartRate(0)
        }
        else if call.method == "queryTimingMeasureHeartRate" {
            //获取24⼩时定时测量状态
            NKBluetoothManager.shared.get24HourHeartRateInterval { interval in
                result("要传给Flutter的数据")
            }
        }
        else if call.method == "queryTodayHeartRate" {
            //查询今天定时测量⼼率数据
            NKBluetoothManager.shared.get24HourHeartRate { data in
                result("要传给Flutter的数据")
            }
        }
        else if call.method == "queryPastHeartRate" {
            //查询昨天定时测量⼼率数据
            NKBluetoothManager.shared.getAgo24HourHeartRate { data in
                result("要传给Flutter的数据")
            }
        }
        else if call.method == "queryMovementHeartRate" {
            //获取运动数据,测量量结果包括⼼⼼率和卡路⾥等其它运动相关数据,保存最近三次
            NKBluetoothManager.shared.getSportData { datas in
                result("要传给Flutter的数据")
            }
        }
        else if call.method == "startMeasureOnceHeartRate" {
            //开启静态⼼率单次测量
            NKBluetoothManager.shared.setStartSingleHR()
        }
        else if call.method == "stopMeasureOnceHeartRate" {
            //结束静态⼼率单次测量,测量结果通过receiveHeartRate(_ heartRate: Int)回调
            NKBluetoothManager.shared.setStopSingleHR()
        }
        else if call.method == "queryHistoryHeartRate" {
            //获取单次⼼率测量历史记录
            NKBluetoothManager.shared.getHeartRecordData { datas in
                
            }
        }
        //MARK: - 血压 -
        else if call.method == "startMeasureBloodPressure" {
            //开始测量⾎压
            NKBluetoothManager.shared.setStartBlood()
        }
        else if call.method == "stopMeasureBloodPressure" {
            //停⽌测量⾎压,测量结果通过receiveBloodPressure(_heartRate: Int, _ sbp: Int, _ dbp: Int)回调
            NKBluetoothManager.shared.setStopBlood()
        }
        else if call.method == "enableContinueBloodPressure" {
            //设置全天⾎压
            NKBluetoothManager.shared.setFullDayBPStatus(open: true)
        }
        else if call.method == "disableContinueBloodPressure" {
            //设置全天⾎压
            NKBluetoothManager.shared.setFullDayBPStatus(open: false)
        }
        else if call.method == "queryContinueBloodPressureState" {
            //获取全天⾎压状态
            NKBluetoothManager.shared.getFullDayBPStatus { status in
                
            }
        }
        else if call.method == "queryLast24HourBloodPressure" {
            //获取全天⾎压数据
            NKBluetoothManager.shared.getFullDayBPData { datas in
                
            }
        }
        else if call.method == "queryHistoryBloodPressure" {
            //获取单次⾎压测量历史记录
            NKBluetoothManager.shared.getBPRecordData { datas in
                
            }
        }
        //MARK: - 血氧 -
        else if call.method == "startMeasureBloodOxygen" {
            //开始测量⾎氧
            NKBluetoothManager.shared.setStartSpO2()
        }
        else if call.method == "stopMeasureBloodOxygen" {
            //停⽌测量⾎氧
            NKBluetoothManager.shared.setStopSpO2()
        }
        else if call.method == "enableTimingMeasureBloodOxygen" {
            //开启定时测量血氧
            NKBluetoothManager.shared.setAutoO2(1)
        }
        else if call.method == "disableTimingMeasureBloodOxygen" {
            //禁用计时测量血氧
            NKBluetoothManager.shared.setAutoO2(0)
        }
        else if call.method == "queryTimingBloodOxygenMeasureState" {
            //查询定时测血氧状态
            NKBluetoothManager.shared.getAutoO2Interval { data, error in
                result("要传给Flutter的数据")
            }
        }
        else if call.method == "queryTimingBloodOxygen" {
            //查询定时测血氧
            NKBluetoothManager.shared.getAutoO2Data { todayData, error in
                
            } _: { yesterdayData, error in
                
            }

        }
        else if call.method == "enableContinueBloodOxygen" {
            //设置全天⾎氧
            NKBluetoothManager.shared.setFullDayO2Status(open: true)
        }
        else if call.method == "disableContinueBloodOxygen" {
            //设置全天⾎氧
            NKBluetoothManager.shared.setFullDayO2Status(open: false)
        }
        else if call.method == "queryContinueBloodOxygenState" {
            //查询持续的血氧状态
            NKBluetoothManager.shared.returnReceiveSpO2Closure { state in
                result("要传给Flutter的数据")
            }
        }
        else if call.method == "queryLast24HourBloodOxygen" {
            //查询最近24小时血氧
            NKBluetoothManager.shared.getFullDayO2Data { datas in
                result("要传给Flutter的数据")
            }
        }
        else if call.method == "queryHistoryBloodOxygen" {
            //获取单次⾎氧测量历史记录
            NKBluetoothManager.shared.getO2RecordData { datas in
                result("要传给Flutter的数据")
            }
        }
        //MARK: - 拍照 - iOS端暂时没有
        else if call.method == "enterCameraView" {
            //进入相机
            NKBluetoothManager.shared.switchCameraView()
        }
        else if call.method == "exitCameraView" {
            //退出相机
            NKBluetoothManager.shared.exitCameraView()
        }
        //MARK: - RSSI - iOS端暂时没有
        else if call.method == "readDeviceRssi" {
            //读取手表的实时RSSI
            
        }
        //MARK: - 心电图测量 -
        else if call.method == "startECGMeasure" {
            //开始测量心电图
            NKBluetoothManager.shared.startECGMeasure()
        }
        else if call.method == "stopECGMeasure" {
            //停⽌⼼电测量
            NKBluetoothManager.shared.stopECGMeasure()
        }
        else if call.method == "isNewECGMeasurementVersion" {
            //检测是否是新的⼼电测量⽅式
            NKBluetoothManager.shared.isNewECGMeasurementVersion { isNew in
                result("要传给Flutter的数据")
            }
        }
        else if call.method == "queryLastMeasureECGData" {
            //查询上次⼼电数据
            NKBluetoothManager.shared.getLastMeasureECGData()
        }
        else if call.method == "sendECGHeartRate" {
            //设置⼼电测量期间⼼率,⽤测量所得到的数据，通过⼼电算法库计算出瞬时⼼率，发送⾄⼿环。
            NKBluetoothManager.shared.sendECGHeartRate(heartRate: 0)
        }
        //MARK: - 语言 -
        else if call.method == "sendDeviceVersion" {
            //设置⼿环当前语⾔版本,⼿环语⾔版本分中⽂版和国际版，中⽂版只显示中⽂，国际版才能切换外语
            NKBluetoothManager.shared.setLanguageVersion(isChinese: true)
        }
        else if call.method == "queryDeviceVersion" {
            //获取手表版本

        }
        else if call.method == "sendDeviceLanguage" {
            //设置⼿环语⾔
            NKBluetoothManager.shared.setLanguage(0)
        }
        else if call.method == "queryDeviceLanguage" {
            //获取当前⼿环语⾔
            NKBluetoothManager.shared.getLanguage { language, error in

            } _: { languages, error in

            }
        }
        //MARK: - 通知 -
        else if call.method == "sendOtherMessageState" {
            //设置其它消息推送状态,开启或者关闭其它消息推送。
            NKBluetoothManager.shared.setNotification(WithTypes: [.facebook,.gmail])
        }
        else if call.method == "queryOtherMessageState" {
            //查询其它消息推送状态,查询其它消息推送状态
            NKBluetoothManager.shared.getNotifications { datas, error in
                result("要传给Flutter的数据")
            }
        }
        else if call.method == "sendMessage" {
            //向手表发送各类消息内容。
            NKBluetoothManager.shared.setMessage("")
        }
        else if call.method == "sendCall0ffHook" {
            //当手表接收到手机类型的信息推送，手表将振动一个固定的时间。调用这个接口来停止手表手表接通或电话挂断时震动。
            
        }
        //MARK: - 久坐提醒 -
        else if call.method == "sendDeviceLanguage" {
            //开启或者关闭久坐提醒。
            NKBluetoothManager.shared.setRemindersToMove(true)
        }
        else if call.method == "querySedentaryReminder" {
            //查询久坐提醒状态
            NKBluetoothManager.shared.getRemindersToMove { state, error in
                result("要传给Flutter的数据")
            }
        }
        else if call.method == "sendSedentaryReminderPeriod" {
            //设置久坐提醒有效时间段
            NKBluetoothManager.shared.setSitRemind(SitRemindModel())
        }
        else if call.method == "querySedentaryReminderPeriod" {
            //获取久坐提醒时间段
            NKBluetoothManager.shared.getSitRemindInfo { data, error in
                result("要传给Flutter的数据")
            }
        }
        //MARK: - 找寻设备 -
        else if call.method == "findDevice" {
            //查找⼿环，⼿环收到此指令以后会震动⼏秒。
            NKBluetoothManager.shared.setFindDevice()
        }
        //MARK: - 关机 -
        else if call.method == "shutDown" {
            //⼿环关机
            NKBluetoothManager.shared.shutDown()
        }
        //MARK: - 勿扰时段 -
        else if call.method == "sendDoNotDistrubTime" {
            //设置勿扰时段,⼿环⽀持勿扰时段，勿扰时段内不显示消息推送
            NKBluetoothManager.shared.setDisturbTime(periodTimeModel())
        }
        else if call.method == "queryDoNotDistrubTime" {
            //查询⼿环设置的勿扰时段
            NKBluetoothManager.shared.getDisturbTime { model, error in
                result("要传给Flutter的数据")
            }
        }
        //MARK: - 呼吸灯 -
        else if call.method == "sendBreathingLight" {
            //设置呼吸灯,一些手表支持呼吸灯，并打开或关闭呼吸灯。
            
        }
        else if call.method == "queryBreathingLight" {
            //获取呼吸灯的状态
            
        }
        //MARK: - 生理周期 -
        else if call.method == "sendPhysiologcalPeriod" {
            //设置⽣理周期提醒
            NKBluetoothManager.shared.setPhysiological(Physiological())
        }
        else if call.method == "queryPhysiologcalPeriod" {
            //查询⽣理周期提醒
            NKBluetoothManager.shared.getPhysiological { data, error in
                
            }
        }
        //MARK: - 查找手机 -
        else if call.method == "startFindPhone" {
            //开始找寻手机
            NKBluetoothManager.shared.sendFindingPhone()
        }
        else if call.method == "stopFindPhone" {
            //结束找寻手机
            NKBluetoothManager.shared.stopFindPhone()
        }
        //MARK: - 播放器 -
        else if call.method == "setMusicPlayerState" {
            //设置播放器状态
            
        }
        else if call.method == "sendSongTitle" {
            //设置歌的标题
            
        }
        else if call.method == "sendLyrics" {
            //设置歌词
            
        }
        else if call.method == "closeMusicControl" {
            //关闭音乐控制
            
        }
        else if call.method == "sendMaxVolume" {
            //设置最大音量
            
        }
        else if call.method == "sendCurrentVolume" {
            //设置当前音量
            
        }
        //MARK: - 喝水提醒 -
        else if call.method == "enableDrinkWaterReminder" {
            //设置喝⽔提醒数据
            NKBluetoothManager.shared.sendDrinkWaterRemind(drinkWaterRemind())
        }
        else if call.method == "disableDrinkWaterReminder" {
            //设置喝⽔提醒数据
            NKBluetoothManager.shared.sendDrinkWaterRemind(drinkWaterRemind())
        }
        else if call.method == "queryDrinkWaterReminderPeriod" {
            //获取喝⽔提醒数据
            NKBluetoothManager.shared.getDrinkWaterRemind { data, error in
                
            }
        }
        //MARK: - 心率预警 -
        else if call.method == "setMaxHeartRate" {
            //设置⼼率预警值
            NKBluetoothManager.shared.sendHeartRateRemind(hrRemind())
        }
        else if call.method == "queryMaxHeartRate" {
            //获取⼼率预警值
            NKBluetoothManager.shared.getHeartRateRemind { data, error in
                
            }
        }
        //MARK: - 锻炼 -
        else if call.method == "startMovement" {
            //开启锻炼
            
        }
        else if call.method == "setMovementState" {
            //设置锻炼状态
            
        }
        else if call.method == "connTainStateEveStm" {
            //监控锻炼状态
            
        }
        //MARK: - 协议版本 -
        else if call.method == "getProtocolVersion" {
            //获取协议版本
            
        }
        //MARK: - 温度 -
        else if call.method == "startMeasureTemp" {
            //开始单次体温测量
            NKBluetoothManager.shared.sendSingleTemperatureStart()
        }
        else if call.method == "stopMeasureTemp" {
            //结束单次体温测量
            NKBluetoothManager.shared.sendSingleTemperatureEnd()
        }
        else if call.method == "enableTimingMeasureTemp" {
            //开启定时温度测量
            NKBluetoothManager.shared.sendAutoTemperature(true)
        }
        else if call.method == "disableTimingMeasureTemp" {
            //禁用定时温度测量
            NKBluetoothManager.shared.sendAutoTemperature(false)
        }
        else if call.method == "queryTimingMeasureTempState" {
            //获取⾃动体温测量开关
            NKBluetoothManager.shared.getAutoTemperatureState { data, error in
                //1：开启；0：关闭
                result("要传给Flutter的数据")
            }
        }
        else if call.method == "queryTimingMeasureTemp" {
            //获取⾃动体温测量数据,每半⼩时⼀个数据
            NKBluetoothManager.shared.getAutoTemperatureData { datas, error in
                
            } _: { datas, error in
                
            }
        }
        //MARK: - 显示的时间
        else if call.method == "sendDisplayTime" {
            //设置亮屏时间
            NKBluetoothManager.shared.sendAutoLockTime(1)
        }
        else if call.method == "queryDisplayTime" {
            //获取亮屏时间
            NKBluetoothManager.shared.getAutoLockTime { data, error in
                result("要传给Flutter的数据")
            }
        }
        //MARK: - 洗手提醒 -
        else if call.method == "enableHandWashingReminder" {
            //开启洗⼿提醒
            NKBluetoothManager.shared.sendHandWashRemind(eventRemind())
        }
        else if call.method == "disableHandWashingReminder" {
            //禁用洗手提醒
            NKBluetoothManager.shared.sendHandWashRemind(eventRemind())
        }
        else if call.method == "queryHandWashingReminderPeriod" {
            //获取洗⼿提醒数据
            NKBluetoothManager.shared.getHandWashRemind { data, error in
                result("要传给Flutter的数据")
            }
        }
        //MARK: -温度 -
        else if call.method == "sendTempUnit" {
            //切换手环的温度系统。
            
        }
        else if call.method == "queryTempUnit" {
            //查询系统温度

        }
        //MARK: - 蓝牙地址 -
        else if call.method == "queryBtAddress" {
            //获取经典的蓝牙地址

        }
        //MARK: - 联系人 -
        else if call.method == "checkSupportQuickContact" {
            //获取联系⼈配置项
            NKBluetoothManager.shared.getContactProfile { model, error in
                result("要传给Flutter的数据")
            }
        }
        else if call.method == "queryContactCount" {
            //获取当前联系⼈个数
            NKBluetoothManager.shared.getContactCount { data, error in
                result("要传给Flutter的数据")
            }
        }
        else if call.method == "checkSupportQuickContact" {
            //获取联系⼈配置项
            NKBluetoothManager.shared.getContactProfile { model, error in
                result("要传给Flutter的数据")
            }
        }
        else if call.method == "sendContact" {
            //设置联系⼈
            NKBluetoothManager.shared.setContact(profile: contactProfileModel(), contacts: [CRPContact()])
        }
        else if call.method == "sendContactAvatar" {
            //设置联系人头像
            NKBluetoothManager.shared.setContact(profile: contactProfileModel(), contacts: [CRPContact()])
        }
        else if call.method == "deleteContact" {
            //删除联系人
            NKBluetoothManager.shared.deleteContact(contactID: 0)
        }
        else if call.method == "deleteContactAvatar" {
            //删除联系人头像
            NKBluetoothManager.shared.deleteContact(contactID: 0)
        }
        //MARK: - 省电模式 -
        else if call.method == "sendBatterySaving" {
            //设置省电状态
            NKBluetoothManager.shared.setPowerSaveState(open: true)
        }
        else if call.method == "queryBatterySaving" {
            //获取省电状态
            NKBluetoothManager.shared.getPowerSaveState { data, error in
                result("要传给Flutter的数据")
            }
        }
        //MARK: - 吃药提醒 -
        else if call.method == "queryPillReminder" {
            //获取当前吃药提醒信息,通过receiveMedicineInfo⽅法返回数据
            NKBluetoothManager.shared.getMedicineInfo()
        }
        else if call.method == "sendPillReminder" {
            //设置吃药提醒
            NKBluetoothManager.shared.setMedicine(medicine: CRPMedicineReminderModel())
        }
        else if call.method == "deletePillReminder" {
            //删除指定id的吃药提醒
            NKBluetoothManager.shared.deleteMedicine(id: 0)
        }
        else if call.method == "clearPillReminder" {
            //删除所有吃药提醒设置
            NKBluetoothManager.shared.deleteAllMedicine()
        }
        //MARK: - 唤醒 -
        else if call.method == "sendTapToWakeState" {
            //设置屏幕轻触唤醒
            NKBluetoothManager.shared.setTapToWake(open: true)
        }
        else if call.method == "queryTapToWakeState" {
            //获取屏幕轻触唤醒设置(0: 关闭，1: 开启)
            NKBluetoothManager.shared.readTapToWake { data, error in
                result("要传给Flutter的数据")
            }
        }
        else if call.method == "queryHistoryTraining" {
            //查询历史锻炼
            
        }
        else if call.method == "queryTraining" {
            //查询锻炼细节
            
        }
        
        
        
    }

}
