import 'dart:async';

import 'package:flutter/material.dart';
import 'package:moyoung_ble_plugin/moyang_ble.dart';

import 'contact_list_page.dart';
import 'devicePage.dart';
import 'package:flutter_contacts/flutter_contacts.dart';
import 'package:permission_handler/permission_handler.dart';

void main() {
  runApp(const MaterialApp(
    title: "moyang ble demo",
    home: MyApp(),
  ));
}

class MyApp extends StatefulWidget {
  const MyApp({Key? key}) : super(key: key);

  @override
  State<MyApp> createState() => _MyAppState();
}

class _MyAppState extends State<MyApp> {
  final _streamSubscriptions = <StreamSubscription<dynamic>>[];
  final MoYangBle _blePlugin = MoYangBle();

  String _permissionTxt = "requestPermissions()";
  String _scanBtnTxt = "startScan()";
  String _cancelScanResult = "cancelScan()";
  String _contactInfo = 'skip 2 contacts';
  final List<BleScanEvent> _deviceList = [];

  @override
  void initState() {
    super.initState();
    subscriptStream();
  }

  void subscriptStream() {
    _streamSubscriptions.add(
      _blePlugin.bleScanEveStm.listen(
        (BleScanEvent event) async {
          setState(() {
            _deviceList.add(event);
          });
        },
      ),
    );
  }

  @override
  void dispose() {
    super.dispose();
    for (final subscription in _streamSubscriptions) {
      subscription.cancel();
    }
  }

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      home: Scaffold(
        appBar: AppBar(
          title: const Text('Plugin example app'),
        ),
        body: Center(
          child: Column(
            children: <Widget>[
              ElevatedButton(
                  child: Text(_permissionTxt),
                  onPressed: requestPermissions),
              ElevatedButton(
                  child: Text(_scanBtnTxt),
                  onPressed: onStartScan),
              ElevatedButton(
                  child: Text(_cancelScanResult),
                  onPressed: cancelScan),

              ElevatedButton(
                  child: Text(_contactInfo),
                  onPressed: selectContact),

              Expanded(
                child: ListView.separated(
                    itemBuilder: (BuildContext context, int index) {
                      return ListTile(
                          title: Text(_deviceList[index].name + ',' + _deviceList[index].address),
                          onTap: () {
                            Navigator.push(context,
                                MaterialPageRoute(builder: (context) {
                                  return NewRoute(
                                    device : _deviceList[index],
                                  );
                                }));
                          });
                    },
                    separatorBuilder: (BuildContext context, int index) {
                      return const Divider(
                        color: Colors.blue,
                      );
                    },
                    itemCount: _deviceList.length),
              )
            ],
          ),
        ),
      ),
    );
  }

  void requestPermissions() {
    [Permission.location, Permission.storage, Permission.manageExternalStorage]
        .request().then((value) => {
      setState(() {
        Map<Permission, PermissionStatus> statuses = value;
        if (statuses[Permission.location] == PermissionStatus.denied) {
          String permissionName = Permission.location.toString();
          _permissionTxt = "$permissionName is denied";
          return;
        }
        if (statuses[Permission.storage] == PermissionStatus.denied) {
          String permissionName = Permission.storage.toString();
          _permissionTxt = "$permissionName is denied";
          return;
        }
        if (statuses[Permission.manageExternalStorage] == PermissionStatus.denied) {
          String permissionName = Permission.manageExternalStorage.toString();
          _permissionTxt = "$permissionName is denied";
          return;
        }

        _permissionTxt = "permissionGranted";
      })

    });
  }

  void onStartScan() {
    if (!mounted) return;
    _blePlugin.startScan.then((value) => {
      setState(() {
        _scanBtnTxt = value ? "Scanning" : "Scan filed";
      })
    }).onError((error, stackTrace) => {
      print(error.toString())
    });
  }

  Future<void> cancelScan() async {
    String resultStr = await _blePlugin.cancelScan;
    if (!mounted) return;
    setState(() {
      _cancelScanResult = 'cancelScan()' + resultStr;
    });
  }

  Future<void> selectContact() async {
    final Contact contact = await Navigator.push(context, MaterialPageRoute(
      builder: (context) => FlutterContactsExample(context),
      )
    );

    if (!mounted) return;

    setState(() {
      String name = contact.name.toString();
      String phone = contact.phones.first.toString();
      _contactInfo = '$name, $phone';
    });
  }
}
