import 'dart:async';

import 'package:moyoung_ble_plugin/impl/moyang_beans.dart';
import 'package:moyoung_ble_plugin/impl/moyoung_ble_impl.dart';
// Export [moyang_beans], [moyang_contants] from the moyang_ble
// so plugin users can use them directly.
export 'package:moyoung_ble_plugin/impl/moyang_beans.dart';
export 'package:moyoung_ble_plugin/impl/moyang_contants.dart';

class MoYangBle {
  /// Constructs a singleton instance of [MoYangBle].
  ///
  /// [MoYangBle] is designed to work as a singleton.
  factory MoYangBle() {
    _singleton ??= MoYangBle._();
    return _singleton!;
  }

  MoYangBle._();

  static MoYangBle? _singleton;

  static MoyoungBleImpl get _platform {
    return MoyoungBleImpl.instance;
  }

  /// This method startScan
  Future<bool> get startScan {
    return _platform.startScan;
  }

  /// This method cancelScan
  Future<String> get cancelScan {
    return _platform.cancelScan;
  }

  /// This method isConnected
  Future<bool> isConnected(String address) {
    return _platform.isConnected(address);
  }

  Future<int> connect(String address) {
    return _platform.connect(address);
  }

  /// This method disconnect
  Future<bool> get disconnect {
    return _platform.disconnect();
  }

  Future<void> get syncTime {
    return _platform.syncTime;
  }

  Future<void> sendTimeSystem(int timeSystemType) {
    return _platform.sendTimeSystem(timeSystemType);
  }

  Future<int> get queryTimeSystem {
    return _platform.queryTimeSystem;
  }

  Future<String> get queryFirmwareVersion {
    return _platform.queryFirmwareVersion;
  }

  Future<void> get queryDeviceBattery {
    return _platform.queryDeviceBattery;
  }

  Future<void> get subscribeDeviceBattery{
    return  _platform.subscribeDeviceBattery;
  }

  Future<FirmwareVersionInfo> get checkFirmwareVersion {
    return _platform.checkFirmwareVersion;
  }

  Future<void> sendUserInfo(CrpUserInfo userInfo) {

    return _platform.sendUserInfo(userInfo);
  }

  Future<void> sendStepLength(int stepLength) {
    return _platform.sendStepLength(stepLength);
  }

  Future<void> sendTodayWeather(CrpTodayWeatherInfo todayWeatherInfo) {
    return _platform.sendTodayWeather(todayWeatherInfo);
  }

  Future<void> sendFutureWeather(CrpTodayWeatherInfo todayWeatherInfo) {
    return _platform.sendFutureWeather(todayWeatherInfo);
  }

  Stream<BleScanEvent> get bleScanEveStm {
    return _platform.bleScanEveStm;
  }

  Stream<int> get connStateEveStm {
    return _platform.connStateEveStm;
  }

  Stream<ConnStepChangeBean> get connStepChangeEveStm {
    return _platform.connStepChangeEveStm;
  }

  //余诗霞:start
  Future<int> get queryMetricSystem  {
    return _platform.queryMetricSystem;
  }

  Future<void> sendMetricSystem(int metricSystemType) {
    return _platform.sendMetricSystem(metricSystemType);
  }

  Future<void> sendQuickView(bool quickViewState){
    return _platform.sendQuickView(quickViewState);
  }

  Future<bool> get queryQuickView{

    return _platform.queryQuickView;
  }

  Future<void> sendQuickViewTime(CrpPeriodTimeInfo crpPeriodTimeInfo){
    return _platform.sendQuickViewTime(crpPeriodTimeInfo);
  }

  Future<Map<dynamic, dynamic>> get queryQuickViewTime{
    return _platform.queryQuickViewTime;
  }

  Future<void> sendGoalSteps(int goalSteps){
    return _platform.sendGoalSteps(goalSteps);
  }

  Future<int> get queryGoalStep{
    return _platform.queryGoalStep;
  }

  Future<void> sendDisplayWatchFace(int watchFaceType){
    return _platform.sendDisplayWatchFace(watchFaceType);
  }

  Future<int> get queryDisplayWatchFace {
    return _platform.queryDisplayWatchFace;
  }

  Future<CrpWatchFaceLayoutInfo> get queryWatchFaceLayout {
    return _platform.queryWatchFaceLayout;
  }

  Future<void> sendWatchFaceLayout(
      CrpWatchFaceLayoutInfo crpWatchFaceLayoutInfo){

    return _platform.sendWatchFaceLayout(crpWatchFaceLayoutInfo);
  }

  Future<Map<dynamic, dynamic>> sendWatchFaceBackground(CrpWatchFaceBackgroundInfo watchFaceBackgroundInfo) async {
    return _platform.sendWatchFaceBackground(watchFaceBackgroundInfo);
  }

  Stream<Map<dynamic, dynamic>> get connLazyFileTransEveStm {
    return _platform.connLazyFileTransEveStm;
  }

  Future<CrpSupportWatchFaceInfo> get querySupportWatchFace {
    return _platform.querySupportWatchFace;
  }

  Future<Map<dynamic, dynamic>> queryWatchFaceStore(
      WatchFaceStoreBean watchFaceStoreBean){

    return _platform.queryWatchFaceStore(watchFaceStoreBean);
  }

  Future<Map<dynamic, dynamic>> queryWatchFaceOfID(int id){
    return _platform.queryWatchFaceOfID(id);
  }

  Future<Map<dynamic, dynamic>> sendWatchFace(CrpCustomizeWatchFaceInfo customizeWatchFaceInfo,int timeout) async {
    return _platform.sendWatchFace(customizeWatchFaceInfo, timeout);
  }

  //表盘到这里结束
  Future<void> sendAlarmClock(CrpAlarmClockInfo crpAlarmClockInfo){
    return _platform.sendAlarmClock(crpAlarmClockInfo);
  }

  Future<List<CrpAlarmClockInfo>> get queryAllAlarmClock{
    return _platform.queryAllAlarmClock;
  }

  //2.16-2.20许蕾完成
  //心率
  Stream<ConnHeartRateBean> get connHeartRateEveStm {
    return _platform.connHeartRateEveStm;
  }

  Future<void> get queryLastDynamicRate{
    return _platform.queryLastDynamicRate;
  }

  Future<void> enableTimingMeasureHeartRate(int interval){
    return _platform.enableTimingMeasureHeartRate(interval);
  }
  /*
  todo 验证
   */
  Future<void> get disableTimingMeasureHeartRate {
    return _platform.disableTimingMeasureHeartRate;
  }

   Future<int> get queryTimingMeasureHeartRate {
    return _platform.queryTimingMeasureHeartRate;
  }

  Future<void> queryTodayHeartRate(int heartRateType) {
    return _platform.queryTodayHeartRate(heartRateType);
  }

  Future<void> get queryPastHeartRate {
    return _platform.queryPastHeartRate;
  }

  Future<void> get queryMovementHeartRate {
    return _platform.queryMovementHeartRate;
  }

  Future<void> get startMeasureOnceHeartRate {
    return _platform.startMeasureOnceHeartRate;
  }

  Future<void> get stopMeasureOnceHeartRate {
    return _platform.stopMeasureOnceHeartRate;
  }

  Future<void> get queryHistoryHeartRate {
    return _platform.queryHistoryHeartRate;
  }

  //血压
  Stream<ConnBloodPressureBean> get connBloodPressureEveStm {
    return _platform.connBloodPressureEveStm;
  }

  Future<void> get startMeasureBloodPressure {
    return _platform.startMeasureBloodPressure;
  }
/*
todo
 */
  Future<void> get stopMeasureBloodPressure {
    return _platform.stopMeasureBloodPressure;
  }

  Future<void> get enableContinueBloodPressure {
    return _platform.enableContinueBloodPressure;
  }

  Future<void> get disableContinueBloodPressure {
    return _platform.disableContinueBloodPressure;
  }

  Future<void> get queryContinueBloodPressureState {
    return _platform.queryContinueBloodPressureState;
  }

  Future<void> get queryLast24HourBloodPressure {
    return _platform.queryLast24HourBloodPressure;
  }

  Future<void> get queryHistoryBloodPressure {
    return _platform.queryHistoryBloodPressure;
  }

  //血氧
  Stream<ConnBloodOxygenBean> get connBloodOxygenEveStm {
    return _platform.connBloodOxygenEveStm;
  }

  Future<void> get startMeasureBloodOxygen {
    return _platform.startMeasureBloodOxygen;
  }

  Future<void> get stopMeasureBloodOxygen {
    return _platform.stopMeasureBloodOxygen;
  }

  Future<void> enableTimingMeasureBloodOxygen(int interval) {
    return _platform.enableTimingMeasureBloodOxygen(interval);
  }

  Future<void> get disableTimingMeasureBloodOxygen {
    return _platform.disableTimingMeasureBloodOxygen;
  }

  Future<void> get queryTimingBloodOxygenMeasureState {
    return _platform.queryTimingBloodOxygenMeasureState;
  }

  Future<void> queryTimingBloodOxygen(String bloodOxygenTimeType) {
    return _platform.queryTimingBloodOxygen(bloodOxygenTimeType);
  }

  Future<void> get enableContinueBloodOxygen {
    return _platform.enableContinueBloodOxygen;
  }

  Future<void> get disableContinueBloodOxygen {
    return _platform.disableContinueBloodOxygen;
  }

  Future<void> get queryContinueBloodOxygenState {
    return _platform.queryContinueBloodOxygenState;
  }

  Future<void> get queryLast24HourBloodOxygen {
    return _platform.queryLast24HourBloodOxygen;
  }

  Future<void> get queryHistoryBloodOxygen {
    return _platform.queryHistoryBloodOxygen;
  }

  //拍照
  Future<void> get enterCameraView {
    return _platform.enterCameraView;
  }

  Future<void> get exitCameraView {
    return _platform.exitCameraView;
  }

  Stream<void> get connCameraEveStm {
    return _platform.connCameraEveStm;
  }

  //电话
  Stream<int> get connPhoneEveStm {
    return _platform.connPhoneEveStm;
  }

  //rssi
  Stream<int> get connDeviceRssiEveStm {
    return _platform.connDeviceRssiEveStm;
  }

  Future<void> get readDeviceRssi {
    return _platform.readDeviceRssi;
  }

  Future<Map<dynamic, dynamic>> setECGChangeListener(String ecgMeasureType) {
    return _platform.setECGChangeListener(ecgMeasureType);
  }

  //egc
  Stream<ConnEgcBean> get connLazyEgcEveStm {
    return _platform.connLazyEgcEveStm;
  }

  Future<void> get startECGMeasure {
    return _platform.startECGMeasure;
  }

  Future<void> get stopECGMeasure {
    return _platform.stopECGMeasure;
  }

  Future<void> get isNewECGMeasurementVersion {
    return _platform.isNewECGMeasurementVersion;
  }

  Future<void> get queryLastMeasureECGData {
    return _platform.queryLastMeasureECGData;
  }

  Future<void> sendECGHeartRate(int heartRate) {
    return _platform.sendECGHeartRate(heartRate);
  }

  Stream<Map<dynamic, dynamic>> get connLazyContactAvatarEveStm {
    return _platform.connLazyContactAvatarEveStm;
  }

  //余诗霞:end
  //yushixia:end

//xulei:start
  //发送手表版本
  Future<void> sendDeviceLanguage(int language) {
    return _platform.sendDeviceLanguage(language);
  }

  Future<Map<dynamic,dynamic>> get queryDeviceLanguage {
    return _platform.queryDeviceLanguage;
  }

  Future<void> sendOtherMessageState(bool messageState) {
    return _platform.sendOtherMessageState(messageState);
  }

  Future<bool> get queryOtherMessageState {
    return _platform.queryOtherMessageState;
  }
  Future<void> sendMessage(CrpMessageInfo crpMessageInfo) {
    return _platform.sendMessage(crpMessageInfo);
  }

  Future<void> get sendCall0ffHook {
    return _platform.sendCall0ffHook;
  }

  Future<void> sendSedentaryReminder(bool sedentaryReminder) {
    return _platform.sendSedentaryReminder(sedentaryReminder);
  }

  Future<bool> get querySedentaryReminder {
    return _platform.querySedentaryReminder;
  }

  Future<void> sendSedentaryReminderPeriod(
      CrpSedentaryReminderPeriodInfo crpSedentaryReminderPeriodInfo) {
    return _platform.sendSedentaryReminderPeriod(crpSedentaryReminderPeriodInfo);
  }

  Future<CrpSedentaryReminderPeriodInfo> get querySedentaryReminderPeriod {
    return _platform.querySedentaryReminderPeriod;
  }

  Future<void> get findDevice {
    return _platform.findDevice;
  }

  Future<void> get shutDown {
    return _platform.shutDown;
  }

  Future<Map<dynamic,dynamic>> get queryDoNotDistrubTime {
    return _platform.queryDoNotDistrubTime;
  }

  Future<void> sendDoNotDistrubTime(CrpPeriodTimeInfo crpPeriodTimeInfo) {
    return _platform.sendDoNotDistrubTime(crpPeriodTimeInfo);
  }

  Future<void> sendBreathingLight(bool breathingLight) {
    return _platform.sendBreathingLight(breathingLight);
  }

  Future<bool> get queryBreathingLight {
    return _platform.queryBreathingLight;
  }
//xulei:end

  /// libaozhong: start
  /// 设置女生生理周期提醒
  Future<void> sendPhysiologcalPeriod(CrpPhysiologcalPeriodInfo info) {
    return _platform.sendPhysiologcalPeriod(info);
  }

  /// 获取女生生理周期提醒
  Future<FirmwareVersionInfo> get queryPhysiologcalPeriod {
    return _platform.queryPhysiologcalPeriod;
  }

  /// 开始找寻手机
  Future<void> get startFindPhone {
    return _platform.startFindPhone;
  }

  /// 结束找寻手机
  Future<void> get stopFindPhone {
    return _platform.stopFindPhone;
  }

  /// 2.35
  /// 设置播放器状态
  Future<void> get setMusicPlayerState {
    return _platform.setMusicPlayerState;
  }

  /// 设置歌的标题
  Future<void> sendSongTitle(String title) {
    return _platform.sendSongTitle(title);
  }

  /// 设置歌词
  Future<void> sendLyrics(String lyrics) {
    return _platform.sendLyrics(lyrics);
  }

  /// 关闭音乐控制
  Future<void> get closeMusicControl {
    return _platform.closeMusicControl;
  }

  /// 设置当前音量
  Future<void> sendCurrentVolume(int volume) {
    return _platform.sendCurrentVolume(volume);
  }

  /// 设置最大音量
  Future<void> sendMaxVolume(int volume) {
    return _platform.sendMaxVolume(volume);
  }

  /// 2.36
  /// 喝水提醒
  Future<void> enableDrinkWaterReminder(
      CrpDrinkWaterPeriodInfo drinkWaterPeriodInfo) {
    return _platform.enableDrinkWaterReminder(drinkWaterPeriodInfo);
  }

  /// 禁用水提醒
  Future<void> get disableDrinkWaterReminder {
    return _platform.disableDrinkWaterReminder;
  }

  /// 查询喝水提醒
  Future<String> get queryDrinkWaterReminderPeriod {
    return _platform.queryDrinkWaterReminderPeriod;
  }

  /// 2.37
  ///  设置心率告警值
  Future<void> get setMaxHeartRate {
    return _platform.setMaxHeartRate;
  }

  /// 查询心跳告警值
  Future<Map<String, dynamic>> get queryMaxHeartRate {
    return _platform.queryMaxHeartRate;
  }

  /// 开始锻炼
  Future<void> startMovement(int i) {
    return _platform.startMovement(i);
  }

  /// 设置锻炼状态
  Future<void> setMovementState(int i) {
    return _platform.setMovementState(i);
  }

  /// 监控锻炼状态
  Stream<String> get connTainStateEveStm {
    return _platform.connTainStateEveStm;
  }

  /// 获取协议版本
  Future<String> get getProtocolVersion {
    return _platform.getProtocolVersion;
  }

  /// 开始测量第一次温度
  Future<void> get startMeasureTemp {
    return _platform.startMeasureTemp;
  }

  /// 温度一次停止测量
  Future<void> get stopMeasureTemp {
    return _platform.stopMeasureTemp;
  }

  /// 开启定时温度测量
  Future<void> get enableTimingMeasureTemp {
    return _platform.enableTimingMeasureTemp;
  }

  /// 禁用定时温度测量
  Future<void> get disableTimingMeasureTemp {
    return _platform.disableTimingMeasureTemp;
  }

  /// 使用实例查询温度检测状态定时开关
  Future<String> get queryTimingMeasureTempState {
    return _platform.queryTimingMeasureTempState;
  }

  /// 查询定时测温结果
  Future<void> get queryTimingMeasureTemp {
    return _platform.queryTimingMeasureTemp;
  }

  /// 设置温度测量结果监听器
  Stream<String> get connTempChangeEveStm {
    return _platform.connTempChangeEveStm;
  }

  /// 设置显示的时间
  Future<void> sendDisplayTime(int time) {
    return _platform.sendDisplayTime(time);
  }

  /// 查询显示时间
  Future<int> get queryDisplayTime {
    return _platform.queryDisplayTime;
  }

  /// 开启洗手提醒功能
  Future<void> enableHandWashingReminder(CrpHandWashingPeriodInfo info) {
    return _platform.enableHandWashingReminder(info);
  }

  /// 禁用洗手提醒
  Future<void> get disableHandWashingReminder {
    return _platform.disableHandWashingReminder;
  }

  /// 查询洗手提醒
  Future<int> get queryHandWashingReminderPeriod {
    return _platform.queryHandWashingReminderPeriod;
  }

  /// 设置本地城市
  Future<void> sendLocalCity(String city) {
    return _platform.sendLocalCity(city);
  }

  /// 切换手链的温度系统
  Future<void> sendTempUnit(int temp) {
    return _platform.sendTempUnit(temp);
  }

  /// 查询系统温度
  Future<void> get queryTempUnit {
    return _platform.queryTempUnit;
  }

  /// 设置亮度
  Future<void> sendBrightness(int brightness) {
    return _platform.sendBrightness(brightness);
  }

  /// 获取亮度
  Future<Map<dynamic, dynamic>> get queryBrightness {
    return _platform.queryBrightness;
  }

  /// 获取经典的蓝牙地址
  Future<String> get queryBtAddress {
    return _platform.queryBtAddress;
  }

  /// 检查支持联系人
  Future<String> get checkSupportQuickContact {
    return _platform.checkSupportQuickContact;
  }

  /// 查询当前联系人数
  Future<int> get queryContactCount {
    return _platform.queryContactCount;
  }

  /// 设置联系人侦听器
  Stream<int> get connContactEveStm {
    return _platform.connContactEveStm;
  }

  /// 设置联系人
  Future<void> sendContact(CrpContactInfo info) {
    return _platform.sendContact(info);
  }

  /// 设置联系人
  // Future<void> sendContactAvatar() {
  //   return _platform.sendContactAvatar();
  // }

  /// 删除联系人
  Future<void> deleteContact(int id) {
    return _platform.deleteContact(id);
  }

  /// 删除联系人
  // Future<void> deleteContactAvatar(int id) {
  //   return _platform.deleteContactAvatar(id);
  // }

  /// 设置省电监听器
  Stream<bool> get connBatterySavingEveStm {
    return _platform.connBatterySavingEveStm;
  }

  /// 设置省电状态
  Future<void> sendBatterySaving(bool enable) {
    return _platform.sendBatterySaving(enable);
  }

  /// 获取省电状态
  Future<void> get queryBatterySaving {
    return _platform.queryBatterySaving;
  }

  /// 查询支持药丸提醒
  Future<String> get queryPillReminder {
    return _platform.queryPillReminder;
  }

  /// 设置药丸提醒
  Future<void> sendPillReminder(CrpPillReminderInfo info) {
    return _platform.sendPillReminder(info);
  }

  /// 删除药丸提醒
  Future<void> deletePillReminder(int id) {
    return _platform.deletePillReminder(id);
  }

  /// 清晰的药丸提醒
  Future<void> get clearPillReminder {
    return _platform.clearPillReminder;
  }

  /// 查询轻按，进入唤醒状态
  Future<bool> get queryTapToWakeState {
    return _platform.queryTapToWakeState;
  }

  /// 设置“轻按”为唤醒状态
  Future<void> sendTapToWakeState(bool enable) {
    return _platform.sendTapToWakeState(enable);
  }

  /// 设置培训侦听器
  Stream<String> get connTrainingEveStm {
    return _platform.connTrainingEveStm;
  }

  /// 查询历史培训
  Future<void> get queryHistoryTraining {
    return _platform.queryHistoryTraining;
  }

  /// 查询培训细节
  Future<void> queryTraining(int id) {
    return _platform.queryTraining(id);
  }

  Stream<Map<dynamic, dynamic>> get connLazyWFFileTransEveStm {
      return _platform.connLazyWFFileTransEveStm;
  }
/// libaozhong: end
}